<?php
/**
*	@file admin_editor_form_handling.php
*	@brief A file to handle forms in admin editor.
*/

/** An array to hold possible errors in submitted form. */
$form_errors = array();

/**
* Function to process admin editor forms.
* Processes admin editor forms according to $_POST variable and stores possible errors to #$form_errors.
* @return void
*/
function process_admin_editor_forms() {
	
	global $form_errors;
	// Boolean to check if form contains errors
	$error = false;
	/** FormHandler for validating and sanitizing the data. */
	$form_handler = new FormHandler();
	/** An array to hold processed form data. */
	$form_data = array();
	
	// Create a new card or edit card form is submitted
	if (isset($_POST['create_new_card']) || isset($_POST['edit_old_card'])) {
		
		$new_or_edit = 'new_card';
		if (isset($_POST['edit_old_card'])) {
			$new_or_edit = 'edit_card';
		}
		
		if (isset($_SESSION['editor']['settings']['new_password'])) {
			unset($_SESSION['editor']['settings']['new_password']);
		}
		if (isset($_SESSION['editor']['settings']['image_folder'])) {
			unset($_SESSION['editor']['settings']['image_folder']);
		}
		if (isset($_POST['notifications'])) {
			unset($_POST['notifications']);
		}
		$form_data[$new_or_edit] = array();
		$form_errors[$new_or_edit] = array();
		
		// Card id field is disabled so this is a work around for passing id
		if (isset($_POST[$new_or_edit]['card_id_hidden'])) {
			$_POST[$new_or_edit]['card_external_id'] = $_POST[$new_or_edit]['card_id_hidden'];
		}
		if (isset($_POST[$new_or_edit]['repetitive'])) {
			$form_data[$new_or_edit]['repetitive'] = 1;
		}
		else {
			$form_data[$new_or_edit]['repetitive'] = 0;
		}
		if (isset($_POST[$new_or_edit]['card_name'])) {
			
			$data = $form_handler->SanitizeString($_POST[$new_or_edit]['card_name'], CARD_NAME_MAX_LENGTH, true);
			
			if (!$data) {
				$error = true;
				$form_errors[$new_or_edit]['card_name'] = $form_handler->_latest_error;
			}
			else {
				$form_data[$new_or_edit]['card_name'] = $data;
			}		
		}
		if (isset($_POST[$new_or_edit]['tags'])) {
			
			$data = $form_handler->SanitizeString($_POST[$new_or_edit]['tags']);
			if (!$data && !empty($_POST[$new_or_edit]['tags'])) {
				$error = true;
				$form_errors[$new_or_edit]['tags'] = $form_handler->_latest_error;
			}
			else {

				$data_array = explode('#', $data);
				$tags = array();
				
				foreach ($data_array as $tag) {
					$trimmed = trim($tag);
					if (!empty($trimmed)) {
						// find if there is a space
						$pos = strrpos($trimmed, " ");
						if ($pos !== false) {
							$trimmed = substr($trimmed, 0, $pos);
						}
						//TODO: validate or filter other unsuitable chars too
						$tags[] = $trimmed;
					}
				}
				$form_data[$new_or_edit]['tags'] = $tags;
			}
		}
		if (isset($_POST[$new_or_edit]['stats'])) {
			
			if (empty($_POST[$new_or_edit]['stats'])) {
				$form_data[$new_or_edit]['stats'] = $_POST[$new_or_edit]['stats'];
			}
			else {
				
				$data = $form_handler->SanitizeString($_POST[$new_or_edit]['stats']);
				if (!$data) {
					$error = true;
					$form_errors[$new_or_edit]['stats'] = $form_handler->_latest_error;
				}
				else {

					$data_array = explode('@', $data);
					$stats = array();
				
					foreach ($data_array as $stat) {
						$trimmed = trim($stat);
						if (!empty($trimmed)) {
							// find if there is a space
							$pos = strrpos($trimmed, " ");
							if ($pos !== false) {
								$trimmed = substr($trimmed, 0, $pos);
							}
							//TODO: validate or filter other unsuitable chars too
							$stats[] = $trimmed;
						}
					}
					$form_data[$new_or_edit]['stats'] = $stats;
				}
			}
		}
		if (isset($_POST[$new_or_edit]['description'])) {
			
			$data = $form_handler->SanitizeString($_POST[$new_or_edit]['description'], CARD_DESCRIPTION_MAX_LENGTH, true);
			
			if (!$data) {
				$error = true;
				$form_errors[$new_or_edit]['description'] = $form_handler->_latest_error;
			}
			else {
				$form_data[$new_or_edit]['description'] = $data;
			}
		}
		
		if (isset($_POST[$new_or_edit]['choices']) && isset($_POST[$new_or_edit]['results'])) {
			
			// First reindex arrays so that removed choices doesn't broke the system
			$_POST[$new_or_edit]['choices'] = array_values($_POST[$new_or_edit]['choices']);
			$_POST[$new_or_edit]['results'] = array_values($_POST[$new_or_edit]['results']);
			foreach ($_POST[$new_or_edit]['results'] as &$choice_results) {
				$choice_results = array_values($choice_results);
			}
			unset($choice_results);
			
			$choice_counter = 0;
			
			foreach ($_POST[$new_or_edit]['choices'] as $choice) {
				
				// If all fields are empty don't add choice
				if (empty($choice['text'])) {
					$empty = true;
					if (isset($_POST[$new_or_edit]['results'][$choice_counter])) {
						$result_counter = 0;
						foreach ($_POST[$new_or_edit]['results'][$choice_counter] as $result) {
							if (!empty($result['weight'])) {
								$empty = false;
							}
							if (!empty($result['text'])) {
								$empty = false;
							}
							if (!empty($result['stat_changes'])) {
								$empty = false;
							}
							if (!empty($result['next_criteria'])) {
								$empty = false;
							}
							$result_counter++;
						}
					}
					if (!$empty) {
						$error = true;
						$form_errors[$new_or_edit]['choices'][$choice_counter]['text'] = localize('ERROR_FORM_HANDLER_EMPTY');
					}
				}
				else {
					
					$data = $form_handler->SanitizeString($choice['text'], CARD_CHOICE_MAX_LENGTH, true);
			
					if (!$data) {
						$error = true;
						$form_errors[$new_or_edit]['choices'][$choice_counter]['text'] = $form_handler->_latest_error;
					}
					else {
						$form_data[$new_or_edit]['choices'][$choice_counter]['text'] = $data;
					}
					if (isset($_POST[$new_or_edit]['results'][$choice_counter])) {
						
						$result_counter = 0;
						$total_weight = 0; // Sum of all results weights must be 100%
						foreach ($_POST[$new_or_edit]['results'][$choice_counter] as $result) {
							
							if (empty($result['text'])) {
								$empty = true;
					
								if (!empty($result['weight'])) {
									$empty = false;
								}
								if (!empty($result['stat_changes'])) {
									$empty = false;
								}
								if (!empty($result['next_criteria'])) {
									$empty = false;
								}
							
								if (!$empty) {
									$error = true;
									$form_errors[$new_or_edit]['results'][$choice_counter]['text'] = localize('ERROR_FORM_HANDLER_EMPTY');
								}
							}
							else {
							
								$data = $form_handler->ValidateInt($result['weight']);
			
								$form_data[$new_or_edit]['results'][$choice_counter][$result_counter]['weight'] = $data;
								$total_weight = $total_weight + intval($data);
							
								$data = $form_handler->SanitizeString($result['text'], CARD_RESULT_MAX_LENGTH, true);
			
								if (!$data) {
									$error = true;
									$form_errors[$new_or_edit]['results'][$choice_counter][$result_counter]['text'] = $form_handler->_latest_error;
								}
								else {
									$form_data[$new_or_edit]['results'][$choice_counter][$result_counter]['text'] = $data;
								}
								
								// TODO: validate stat_changes better
								$data = $form_handler->SanitizeString($result['stat_changes']);
			
								if (!$data && !empty($result['stat_changes'])) {
									$error = true;
									$form_errors[$new_or_edit]['results'][$choice_counter][$result_counter]['stat_changes'] = $form_handler->_latest_error;
								}
								else {
									$form_data[$new_or_edit]['results'][$choice_counter][$result_counter]['stat_changes'] = $data;
								}
								// TODO: validate next_criteria better
								$data = $form_handler->SanitizeString($result['next_criteria']);
			
								if (!$data && !empty($result['next_criteria'])) {
									$error = true;
									$form_errors[$new_or_edit]['results'][$choice_counter][$result_counter]['next_criteria'] = $form_handler->_latest_error;
								}
								else {
									$form_data[$new_or_edit]['results'][$choice_counter][$result_counter]['next_criteria'] = $data;
								}
							}
							$result_counter++;
						}	
						// Balance results weights
						$weight_left = 100;
						$weightless_results_indexes = array();
						
						for ($k = 0; $k < count($form_data[$new_or_edit]['results'][$choice_counter]); $k++) {
			
							$weight_left = $weight_left - $form_data[$new_or_edit]['results'][$choice_counter][$k]['weight'];
			
							if ($form_data[$new_or_edit]['results'][$choice_counter][$k]['weight'] == 0) {
								$weightless_results_indexes[] = $k;
							}
						}	
						// If weights don't add up to 100 % and there's no weightless results give error
						if (($weight_left > 0 && count($weightless_results_indexes) == 0) || $weight_left < 0 || ($weight_left == 0 && count($weightless_results_indexes) > 0)) {	
								
							$error = true;
							$result_counter = 0;
							$index = 0;
							// Show only one error from one result set:
							if ($choice_counter > 0) {
								$index = $choice_counter - 1;
							}
							foreach ($_POST[$new_or_edit]['results'][$index] as $result) {
								if (!isset($form_errors[$new_or_edit]['results'][$choice_counter][$result_counter]['weight'])) {
									$form_errors[$new_or_edit]['results'][$choice_counter][$result_counter]['weight'] = localize('ERROR_ADMIN_EDITOR_RESULT_WEIGHT');
								}
								$result_counter++;
							}
						}
						else {
							// Balance weightless results
							if (count($weightless_results_indexes) > 0) {
			
								$weight = ceil($weight_left/count($weightless_results_indexes));
								for ($k = 0; $k < count($form_data[$new_or_edit]['results'][$choice_counter]); $k++) {
			
									if (in_array($k, $weightless_results_indexes)) {
											
										if ($weight > $weight_left) {
											$weight = $weight_left;
										}
										$weight_left = $weight_left - $weight;
										$form_data[$new_or_edit]['results'][$choice_counter][$k]['weight'] = $weight;
									}
								}
							}
						}
					}
				}
				$choice_counter++;
			}
		}
		
		if (isset($_POST[$new_or_edit]['expert_advice'])) {
			
			if (empty($_POST[$new_or_edit]['expert_advice'])) {
				$form_data[$new_or_edit]['expert_advice'] = $_POST[$new_or_edit]['expert_advice'];
			}
			else {
				$data = $form_handler->SanitizeString($_POST[$new_or_edit]['expert_advice'], CARD_ADVICE_MAX_LENGTH, true);
			
				if (!$data) {
					$error = true;
					$form_errors[$new_or_edit]['expert_advice'] = $form_handler->_latest_error;
				}
				else {
					$form_data[$new_or_edit]['expert_advice'] = $data;
				}
			}
		}
		if (isset($_POST[$new_or_edit]['comment'])) {
			
			if (empty($_POST[$new_or_edit]['comment'])) {
				$form_data[$new_or_edit]['comment'] = $_POST[$new_or_edit]['comment'];
			}
			else {
				$data = $form_handler->SanitizeString($_POST[$new_or_edit]['comment'], CARD_COMMENT_MAX_LENGTH, true);
			
				if (!$data) {
					$error = true;
					$form_errors[$new_or_edit]['comment'] = $form_handler->_latest_error;
				}
				else {
					$form_data[$new_or_edit]['comment'] = $data;
				}
			}
		}
		if (isset($_FILES[$new_or_edit]['name']['picture_link']) && !empty($_FILES[$new_or_edit]['name']['picture_link'])) {
			
			$file_name = $form_handler->SanitizeString($_FILES[$new_or_edit]['name']['picture_link']);
				
			if (!$file_name) {
				$error = true;
				$form_errors[$new_or_edit]['picture_link'] = $form_handler->_latest_error;
			}
			else {
					
				// Check that attachment isn't too big
				if ($_FILES[$new_or_edit]['size']['picture_link'] > CARD_ATTACHMENT_MAX_SIZE) {
					$error = true;
					$form_errors[$new_or_edit]['picture_link'] = localize("ERROR_FORM_HANDLER_ATTACHMENT_MAX_SIZE");
				}
				if (!$error) {
					$form_data[$new_or_edit]['picture_link'] = $file_name;
				}
			}
		}
		elseif (isset($_POST[$new_or_edit]['attachment_text_hidden'])) {
			
			$_POST[$new_or_edit]['attachment_text'] = $_POST['edit_card']['attachment_text_hidden'];
			$_POST[$new_or_edit]['picture_link'] = $_POST['edit_card']['attachment_text_hidden'];
			// TODO: validate attachment
			if (empty($_POST[$new_or_edit]['picture_link'])) {
				$form_data[$new_or_edit]['picture_link'] = '';
			}
			else {
			
				$data = $form_handler->SanitizeString($_POST[$new_or_edit]['picture_link']);
				
				if (!$data) {
					$error = true;
					$form_errors[$new_or_edit]['picture_link'] = $form_handler->_latest_error;
				}
				else {
					$form_data[$new_or_edit]['picture_link'] = $data;
				}
			}
		}
		else {
			$form_data[$new_or_edit]['picture_link'] = '';
		}
		
		if (isset($_POST[$new_or_edit]['default_lang'])) {
			
			$data = $form_handler->SanitizeString($_POST[$new_or_edit]['default_lang']);
			
			if (!$data) {
				$error = true;
				$form_errors[$new_or_edit]['default_lang'] = $form_handler->_latest_error;
			}
			else {
				$form_data[$new_or_edit]['default_lang'] = $data;
			}
		}
		if (isset($_POST[$new_or_edit]['translations'])) {
			
			$data = $form_handler->SanitizeString($_POST[$new_or_edit]['translations']);
			
			if (!$data) {
				$error = true;
				$form_errors[$new_or_edit]['translations'] = $form_handler->_latest_error;
			}
			else {
				$form_data[$new_or_edit]['translations'] = $data;
			}
		}
		// If form is valid
		if (!$error) {
			
			if (isset($_SESSION['admin']['game']['game_id']) && isset($_SESSION['user']['user_id'])) {
				
				$game_id = $_SESSION['admin']['game']['game_id'];
				$repetitive = $form_data[$new_or_edit]['repetitive'];
				$comment = $form_data[$new_or_edit]['comment'];
				
				if ($new_or_edit == 'edit_card') {
					
					if (isset($_POST[$new_or_edit]['card_id']) && !empty($_POST[$new_or_edit]['card_id'])) {
						
						$card_id = doubleval($_POST[$new_or_edit]['card_id']);
						$card_external_id = doubleval($_POST[$new_or_edit]['card_external_id']);
						$editor_id = doubleval($_SESSION['user']['user_id']);
					}
				}
				else {
					$creator_id = $_SESSION['user']['user_id'];
				}
				//TODO: remove old stats
				$stats = '';
				$stat_reqs = array();
				
				if (!empty($form_data[$new_or_edit]['stats'])) {
					
					$stats = implode(" @", $form_data[$new_or_edit]['stats']);
					if (!empty($stats)) {
						$stats = '@' . $stats;
					}
				}
				$attachment = $form_data[$new_or_edit]['picture_link'];
				
				global $image_folder;
				$uploaddir = '..' . DIRECTORY_SEPARATOR . $image_folder;
				
				if (!empty($_SESSION['admin']['game']['image_folder'])) {
					$uploaddir = '..' . DIRECTORY_SEPARATOR . $_SESSION['admin']['game']['image_folder'];
				}
				$uploaddir = str_replace(array('/', '\\'), DIRECTORY_SEPARATOR, $uploaddir);
				
				// Check if user has added file
				if ($_FILES[$new_or_edit]['size']['picture_link'] != 0 ) {
					
					// Create directory if not exists
					if (!is_dir($uploaddir)) {
						@mkdir($uploaddir, 0777, true);
					}
					// Picture name
					$picturename =  $_SESSION['admin']['game']['name'] . '_' . $attachment;
					$picture = generateFilename($picturename, $uploaddir);
					$uploadfile2 = $uploaddir . $picture;
					$attachment = $picture;
				
					if (!move_uploaded_file($_FILES[$new_or_edit]['tmp_name']['picture_link'], $uploadfile2)) {
    					$attachment = '';
					}
				}
				$card_name = $form_data[$new_or_edit]['card_name'];
				$description = $form_data[$new_or_edit]['description'];
				$expert_advice = $form_data[$new_or_edit]['expert_advice'];
				$default_lang = $form_data[$new_or_edit]['default_lang'];
				$db = DB::getInstance();
				
				if ($new_or_edit == 'edit_card') {
				
					$current_translation = $form_data[$new_or_edit]['translations'];
					$is_default = 1;
					if ($default_lang != $current_translation) {
						$is_default = 0;
					}
				
					$db->editCard($card_id, $card_external_id, $repetitive, $editor_id, $stats, $comment, $attachment, $_SESSION['admin']['game']['game_id']);
					if ($_SESSION['admin']['game']['latest_card_id'] < $card_external_id) {
						$_SESSION['admin']['game']['latest_card_id'] = $card_external_id;
					}
					//TODO: make private function and add these to createCard
					$db->addCardTags($form_data[$new_or_edit]['tags'], $card_id);
					//TODO: add stat reqs
					//$db->addCardStatReqs($stat_reqs, $card_id);
					$db->updateCardTranslation($card_id, $card_name, $description, $expert_advice, $current_translation, $is_default, $default_lang);
					$db->updateCardChoicesAndResults($card_id, $form_data[$new_or_edit]['choices'], $form_data[$new_or_edit]['results'], $current_translation, $is_default, $default_lang);
				}
				else {
					// Increase and update latest card id
					$latest_card_id = $_SESSION['admin']['game']['latest_card_id'] + 1;
				
					$card_id = $db->createCard($latest_card_id, $game_id, $repetitive, $creator_id, $stats, $comment, $attachment);
				
					if ($card_id > 0) {
						$_SESSION['admin']['game']['latest_card_id'] = $latest_card_id;
						//TODO: make private function and add these  to createCard
						$db->addCardTags($form_data['new_card']['tags'], $card_id);
						$db->addCardTranslation($card_id, $card_name, $description, $expert_advice, $default_lang, true);
						$db->addCardChoicesAndResults($card_id, $form_data['new_card']['choices'], $form_data['new_card']['results'], $default_lang, true);
					}
					else {
						$error = true;
					}
				}
			}
			else {
				$error = true;
			}
			if (!$error) {
				
				unset($_POST[$new_or_edit]);
				if ($new_or_edit == 'edit_card') {
					unset($_POST['edit_old_card']);
					$_POST['notifications'] = array();
					$_POST['notifications']['card_edited'] = true;
				}
				else {
					unset($_POST['create_new_card']);
					$_POST['notifications'] = array();
					$_POST['notifications']['new_card_created'] = true;
				}
			}
			else {
				$_POST['notifications'] = array();
				if ($new_or_edit == 'edit_card') {
					$_POST['notifications']['card_edited'] = false;
				}
				else {
					$_POST['notifications']['new_card_created'] = false;
				}
			}
		}
	}
	
	// Edit cards form is submitted
	if (isset($_POST['edit_multiple_cards'])) {
		
		if (isset($_SESSION['editor']['settings']['new_password'])) {
			unset($_SESSION['editor']['settings']['new_password']);
		}
		if (isset($_SESSION['editor']['settings']['image_folder'])) {
			unset($_SESSION['editor']['settings']['image_folder']);
		}
		if (isset($_POST['notifications'])) {
			unset($_POST['notifications']);
		}
		$form_data['edit_cards'] = array();
		$form_errors['edit_cards'] = array();
		
		// Card ids field is disabled so this is a work around for passing id
		if (isset($_POST['edit_cards']['card_ids_hidden'])) {
			$_POST['edit_cards']['card_external_ids'] = $_POST['edit_cards']['card_ids_hidden'];
		}
		if (isset($_POST['edit_cards']['repetitive_enabled']) && $_POST['edit_cards']['repetitive_enabled'] == '1') {
			if (isset($_POST['edit_cards']['repetitive'])) {
				$form_data['edit_cards']['repetitive'] = 1;
			}
			else {
				$form_data['edit_cards']['repetitive'] = 0;
			}
		}
		if (isset($_POST['edit_cards']['add_tags'])) {
			
			if (!empty($_POST['edit_cards']['add_tags'])) {
				
				$data = $form_handler->SanitizeString($_POST['edit_cards']['add_tags']);
				if (!$data) {
					$error = true;
					$form_errors['edit_cards']['add_tags'] = $form_handler->_latest_error;
				}
				else {

					$data_array = explode('#', $data);
					$tags = array();
				
					foreach ($data_array as $tag) {
						$trimmed = trim($tag);
						if (!empty($trimmed)) {
							// find if theres space
							$pos = strrpos($trimmed, " ");
							if ($pos !== false) {
								$trimmed = substr($trimmed, 0, $pos);
							}
							$tags[] = $trimmed;
						}
					}
					$form_data['edit_cards']['add_tags'] = $tags;
				}
			}
			else {
					$form_data['edit_cards']['add_tags'] = array();
			}
		}
		if (isset($_POST['edit_cards']['remove_tags'])) {
			
			if (!empty($_POST['edit_cards']['remove_tags'])) {
				
				$data = $form_handler->SanitizeString($_POST['edit_cards']['remove_tags']);
				if (!$data) {
					$error = true;
					$form_errors['edit_cards']['remove_tags'] = $form_handler->_latest_error;
				}
				else {

					$data_array = explode('#', $data);
					$tags = array();
				
					foreach ($data_array as $tag) {
						$trimmed = trim($tag);
						if (!empty($trimmed)) {
							// find if there is a space
							$pos = strrpos($trimmed, " ");
							if ($pos !== false) {
								$trimmed = substr($trimmed, 0, $pos);
							}
							$tags[] = $trimmed;
						}
					}
					$form_data['edit_cards']['remove_tags'] = $tags;
				}
			}
			else {
					$form_data['edit_cards']['remove_tags'] = array();
			}
		}
		
		if (isset($_POST['edit_cards']['add_stats'])) {
			
			if (empty($_POST['edit_cards']['add_stats'])) {
				$form_data['edit_cards']['add_stats'] = array();
			}
			else {
				$data = $form_handler->SanitizeString($_POST['edit_cards']['add_stats']);
				if (!$data) {
					$error = true;
					$form_errors['edit_cards']['add_stats'] = $form_handler->_latest_error;
				}
				else {

					$data_array = explode('@', $data);
					$stats = array();
				
					foreach ($data_array as $stat) {
						$trimmed = trim($stat);
						if (!empty($trimmed)) {
							// find if there is a space
							$pos = strrpos($trimmed, " ");
							if ($pos !== false) {
								$trimmed = substr($trimmed, 0, $pos);
							}
							$stats[] = $trimmed;
						}
					}
					$form_data['edit_cards']['add_stats'] = $stats;
				}
			}
		}
		
		if (isset($_POST['edit_cards']['remove_stats'])) {
			
			if (empty($_POST['edit_cards']['remove_stats'])) {
				$form_data['edit_cards']['remove_stats'] = array();
			}
			else {
				$data = $form_handler->SanitizeString($_POST['edit_cards']['remove_stats']);
				if (!$data) {
					$error = true;
					$form_errors['edit_cards']['remove_stats'] = $form_handler->_latest_error;
				}
				else {

					$data_array = explode('@', $data);
					$stats = array();
				
					foreach ($data_array as $stat) {
						$trimmed = trim($stat);
						if (!empty($trimmed)) {
							// find if there is a space
							$pos = strrpos($trimmed, " ");
							if ($pos !== false) {
								$trimmed = substr($trimmed, 0, $pos);
							}
							$stats[] = $trimmed;
						}
					}
					$form_data['edit_cards']['remove_stats'] = $stats;
				}
			}
		}
		
		if (isset($_POST['edit_cards']['comment'])) {
			
			if (empty($_POST['edit_cards']['comment'])) {
				$form_data['edit_cards']['comment'] = $_POST['edit_cards']['comment'];
			}
			else {
				$data = $form_handler->SanitizeString($_POST['edit_cards']['comment'], CARD_COMMENT_MAX_LENGTH, true);
			
				if (!$data) {
					$error = true;
					$form_errors['edit_cards']['comment'] = $form_handler->_latest_error;
				}
				else {
					$form_data['edit_cards']['comment'] = $data;
				}
			}
		}
		
		if (isset($_POST['edit_cards']['picture_enabled']) && $_POST['edit_cards']['picture_enabled'] == '1') {
			if (isset($_FILES['edit_cards']['name']['picture_link']) && !empty($_FILES['edit_cards']['name']['picture_link'])) {
			
				$file_name = $form_handler->SanitizeString($_FILES['edit_cards']['name']['picture_link']);
				
				if (!$file_name) {
					$error = true;
					$form_errors['edit_cards']['picture_link'] = $form_handler->_latest_error;
				}
				else {
					
					// Check that attachment isn't too big
					if ($_FILES['edit_cards']['size']['picture_link'] > CARD_ATTACHMENT_MAX_SIZE) {
						$error = true;
						$form_errors['edit_cards']['picture_link'] = localize("ERROR_FORM_HANDLER_ATTACHMENT_MAX_SIZE");
					}
					if (!$error) {
						$form_data['edit_cards']['picture_link'] = $file_name;
					}
				}
			}
			else {
				$form_data['edit_cards']['picture_link'] = '';
			}
		}
		
		// If form is valid
		if (!$error) {
			
			if (isset($_SESSION['admin']['game']['game_id']) && isset($_SESSION['user']['user_id']) && isset($_POST['edit_cards']['card_ids']) && !empty($_POST['edit_cards']['card_ids'])) {
				
				$editor_id = doubleval($_SESSION['user']['user_id']);
				
				$card_ids = explode(', ', $_POST['edit_cards']['card_ids']);
				$card_external_ids = explode(', ', $_POST['edit_cards']['card_external_ids']);
				foreach ($card_ids as &$id) {
					$id = doubleval($id);
				}
				unset($id);
				foreach ($card_external_ids as &$id) {
					$id = doubleval($id);
				}
				$db = DB::getInstance();
				
				$new_attachment = '';
				// Check if attachment exists here so that every card doesn't need to upload same picture multiple times
				if (isset($form_data['edit_cards']['picture_link'])) {
					
					$new_attachment = $form_data['edit_cards']['picture_link'];
				
					global $image_folder;
					$uploaddir = '..' . DIRECTORY_SEPARATOR . $image_folder;
				
					if (!empty($_SESSION['admin']['game']['image_folder'])) {
						$uploaddir = '..' . DIRECTORY_SEPARATOR . $_SESSION['admin']['game']['image_folder'];
					}
					$uploaddir = str_replace(array('/', '\\'), DIRECTORY_SEPARATOR, $uploaddir);
				
					// Check if user has add file
					if ($_FILES['edit_cards']['size']['picture_link'] != 0 ) {
					
						// Create directory if not exists
						if (!is_dir($uploaddir)) {
							@mkdir($uploaddir, 0777, true);
						}
						
						// Picture name
						$picturename =  $_SESSION['admin']['game']['name'] . '_' . $new_attachment;
						$picture = generateFilename($picturename, $uploaddir);
						$uploadfile2 = $uploaddir . $picture;
						$new_attachment = $picture;
							
						if (!move_uploaded_file($_FILES['edit_cards']['tmp_name']['picture_link'], $uploadfile2)) {
    						$new_attachment = '';
						}
					}
				}
				$counter = 0;
				// Make changes to all cards
				foreach ($card_ids as $card_id) {
					// First get cards current info
					$card = $db->getCard($card_id);
					$card_external_id = $card_external_ids[$counter];
					$repetitive = $card['repetitive'];
					$stats = $card['stats'];
					// Remove @ signs
					foreach ($stats as &$stat) {
						$stat = str_replace('@', '', $stat);
					}
					$comment = $card['comment'];
					$attachment = $card['attachment'];
					
					$tags = $card['tags'];
					
					// Check if attachment exists
					if (isset($form_data['edit_cards']['picture_link'])) {
						$attachment = $new_attachment;
					}
					// Then update card info
					if (isset($form_data['edit_cards']['repetitive'])) {
						$repetitive = $form_data['edit_cards']['repetitive'];
					}
					if (isset($form_data['edit_cards']['comment'])) {
						$comment = $form_data['edit_cards']['comment'];
					}
					// Add new stats
					if (isset($form_data['edit_cards']['add_stats'])) {
						foreach ($form_data['edit_cards']['add_stats'] as $new_stat) {
							if (!in_array($new_stat, $stats)) {
								$stats[] = $new_stat;
							}
						}
					}
					// Remove stats
					if (isset($form_data['edit_cards']['remove_stats'])) {
						foreach ($form_data['edit_cards']['remove_stats'] as $stat_to_remove) {
							if (in_array($stat_to_remove, $stats)) {
								// Remove stat
								$stats = array_diff($stats, array($stat_to_remove));
							}
						}
					}
					// Make stat string
					$stat_reqs = '';
				
					if (!empty($stats)) {
						$stat_reqs = implode(" @", $stats);
						if (!empty($stat_reqs)) {
							$stat_reqs = '@' . $stat_reqs;
						}
					}
					// Add new tags
					if (isset($form_data['edit_cards']['add_tags'])) {
						foreach ($form_data['edit_cards']['add_tags'] as $new_tag) {
							if (!in_array($new_tag, $tags)) {
								$tags[] = $new_tag;
							}
						}
					}
					// Remove tags
					if (isset($form_data['edit_cards']['remove_tags'])) {
						foreach ($form_data['edit_cards']['remove_tags'] as $tag_to_remove) {
							if (in_array($tag_to_remove, $tags)) {
								// Remove stat
								$tags = array_diff($tags, array($tag_to_remove));
							}
						}
					}
					// Update card
					$db->editCard($card_id, $card_external_id, $repetitive, $editor_id, $stat_reqs, $comment, $attachment, $_SESSION['admin']['game']['game_id']);
					if ($_SESSION['admin']['game']['latest_card_id'] < $card_external_id) {
						$_SESSION['admin']['game']['latest_card_id'] = $card_external_id;
					}
					//TODO: make private function and add these to editCard
					$db->addCardTags($tags, $card_id);
					//TODO: add stat reqs
					//$db->addCardStatReqs($stat_reqs, $card_id);
					$counter++;
				}
			}
			else {
				$error = true;
			}
			if (!$error) {
				unset($_POST['edit_cards']);
				unset($_POST['edit_multiple_cards']);
				$_POST['notifications'] = array();
				$_POST['notifications']['card_edited'] = true;
			}
			else {
				$_POST['notifications'] = array();
				$_POST['notifications']['card_edited'] = false;
			}
		}
	}
	
	// Change background color form is submitted
	if (isset($_POST['change_background_color']) || isset($_POST['change_text_color']) || isset($_POST['change_link_color']) || isset($_POST['change_link_hover_color']) || isset($_POST['change_button_color']) || isset($_POST['change_button_hover_color'])) {
		
		if (isset($_POST['notifications'])) {
			unset($_POST['notifications']);
		}
		$form_data['editor'] = array();
		$form_errors['editor']['settings'] = array();
		
		if (isset($_POST['editor']['settings']['background_color'])) {
			
			if (empty($_POST['editor']['settings']['background_color'])) {
				$form_data['settings']['background_color'] = $_POST['editor']['settings']['background_color'];
			}
			else {
			
				$data = $form_handler->SanitizeString($_POST['editor']['settings']['background_color']);
				
				if (!$data) {
					$error = true;
					$form_errors['editor']['settings']['background_color'] = $form_handler->_latest_error;
				}
				else {
					$form_data['settings']['background_color'] = $data;
				}
			}
		}
		if (isset($_POST['editor']['settings']['text_color'])) {
			
			if (empty($_POST['editor']['settings']['text_color'])) {
				$form_data['settings']['text_color'] = $_POST['editor']['settings']['text_color'];
			}
			else {
			
				$data = $form_handler->SanitizeString($_POST['editor']['settings']['text_color']);
				
				if (!$data) {
					$error = true;
					$form_errors['editor']['settings']['text_color'] = $form_handler->_latest_error;
				}
				else {
					$form_data['settings']['text_color'] = $data;
				}
			}
		}
		if (isset($_POST['editor']['settings']['link_color'])) {
			
			if (empty($_POST['editor']['settings']['link_color'])) {
				$form_data['settings']['link_color'] = $_POST['editor']['settings']['link_color'];
			}
			else {
			
				$data = $form_handler->SanitizeString($_POST['editor']['settings']['link_color']);
				
				if (!$data) {
					$error = true;
					$form_errors['editor']['settings']['link_color'] = $form_handler->_latest_error;
				}
				else {
					$form_data['settings']['link_color'] = $data;
				}
			}
		}
		if (isset($_POST['editor']['settings']['link_hover_color'])) {
			
			if (empty($_POST['editor']['settings']['link_hover_color'])) {
				$form_data['settings']['link_hover_color'] = $_POST['editor']['settings']['link_hover_color'];
			}
			else {
			
				$data = $form_handler->SanitizeString($_POST['editor']['settings']['link_hover_color']);
				
				if (!$data) {
					$error = true;
					$form_errors['editor']['settings']['link_hover_color'] = $form_handler->_latest_error;
				}
				else {
					$form_data['settings']['link_hover_color'] = $data;
				}
			}
		}
		if (isset($_POST['editor']['settings']['button_color'])) {
			
			if (empty($_POST['editor']['settings']['button_color'])) {
				$form_data['settings']['button_color'] = $_POST['editor']['settings']['button_color'];
			}
			else {
			
				$data = $form_handler->SanitizeString($_POST['editor']['settings']['button_color']);
				
				if (!$data) {
					$error = true;
					$form_errors['editor']['settings']['button_color'] = $form_handler->_latest_error;
				}
				else {
					$form_data['settings']['button_color'] = $data;
				}
			}
		}
		if (isset($_POST['editor']['settings']['button_hover_color'])) {
			
			if (empty($_POST['editor']['settings']['button_hover_color'])) {
				$form_data['settings']['button_hover_color'] = $_POST['editor']['settings']['button_hover_color'];
			}
			else {
			
				$data = $form_handler->SanitizeString($_POST['editor']['settings']['button_hover_color']);
				
				if (!$data) {
					$error = true;
					$form_errors['editor']['settings']['button_hover_color'] = $form_handler->_latest_error;
				}
				else {
					$form_data['settings']['button_hover_color'] = $data;
				}
			}
		}
		// If form is valid
		if (!$error) {
			
			unset($_POST['editor']['settings']['background_color']);
			unset($_POST['change_background_color']);
			unset($_POST['editor']['settings']['text_color']);
			unset($_POST['change_text_color']);
			unset($_POST['editor']['settings']['link_color']);
			unset($_POST['change_link_color']);
			unset($_POST['editor']['settings']['link_hover_color']);
			unset($_POST['change_link_hover_color']);
			unset($_POST['editor']['settings']['button_color']);
			unset($_POST['change_button_color']);
			unset($_POST['editor']['settings']['button_hover_color']);
			unset($_POST['change_button_hover_color']);
			
			if (isset($_SESSION['admin']['game']['game_id'])) {
				
				if (isset($form_data['settings']['background_color'])) {
					$_SESSION['admin']['game']['background_color'] = $form_data['settings']['background_color'];
					$_POST['notifications'] = array();
					$_POST['notifications']['background_color_changed'] = true;
				}
				if (isset($form_data['settings']['text_color'])) {
					$_SESSION['admin']['game']['text_color'] = $form_data['settings']['text_color'];
					$_POST['notifications'] = array();
					$_POST['notifications']['text_color_changed'] = true;
				}
				if (isset($form_data['settings']['link_color'])) {
					$_SESSION['admin']['game']['link_color'] = $form_data['settings']['link_color'];
					$_POST['notifications'] = array();
					$_POST['notifications']['link_color_changed'] = true;
				}
				if (isset($form_data['settings']['link_hover_color'])) {
					$_SESSION['admin']['game']['link_hover_color'] = $form_data['settings']['link_hover_color'];
					$_POST['notifications'] = array();
					$_POST['notifications']['link_hover_color_changed'] = true;
				}
				if (isset($form_data['settings']['button_color'])) {
					$_SESSION['admin']['game']['button_color'] = $form_data['settings']['button_color'];
					$_POST['notifications'] = array();
					$_POST['notifications']['button_color_changed'] = true;
				}
				if (isset($form_data['settings']['button_hover_color'])) {
					$_SESSION['admin']['game']['button_hover_color'] = $form_data['settings']['button_hover_color'];
					$_POST['notifications'] = array();
					$_POST['notifications']['button_hover_color_changed'] = true;
				}
				$game = $_SESSION['admin']['game'];
				$db = DB::getInstance();
				$db->updateGame($game);
			}
		}
		/*else {
			$_POST['notifications'] = array();
			$_POST['notifications']['background_color_changed'] = false;
		}*/
	}
	
	// Change background tile form is submitted
	if (isset($_POST['change_background_tile'])) {
		
		if (isset($_POST['notifications'])) {
			unset($_POST['notifications']);
		}
		$form_data['editor'] = array();
		$form_errors['editor']['settings'] = array();
		
		if (isset($_FILES['editor']['name']['settings']['background_tile']) && !empty($_FILES['editor']['name']['settings']['background_tile'])) {

			$file_name = $form_handler->SanitizeString($_FILES['editor']['name']['settings']['background_tile']);
			
			if (!$file_name) {
				$error = true;
				$form_errors['editor']['settings']['background_tile'] = $form_handler->_latest_error;
			}
			else {		
				// Check that background_tile isn't too big
				if ($_FILES['editor']['size']['settings']['background_tile'] > CARD_ATTACHMENT_MAX_SIZE) {
					$error = true;
					$form_errors['editor']['settings']['background_tile'] = localize("ERROR_FORM_HANDLER_FILE_MAX_SIZE");
				}
				if (!$error) {
					$form_data['settings']['background_tile'] = $file_name;
				}
			}
		}
		else {
			$form_data['settings']['background_tile'] = '';
			if (isset($_POST['editor']['settings']['background_tile_text_hidden'])) {
				$form_data['settings']['background_tile'] = $_POST['editor']['settings']['background_tile_text_hidden'];
			}
		}
		// If form is valid
		if (!$error) {
			
			$background_tile = $form_data['settings']['background_tile'];
				
			global $image_folder;
			$uploaddir = '..' . DIRECTORY_SEPARATOR . $image_folder;
				
			if (!empty($_SESSION['admin']['game']['image_folder'])) {
				$uploaddir = '..' . DIRECTORY_SEPARATOR . $_SESSION['admin']['game']['image_folder'];
			}
			$uploaddir = str_replace(array('/', '\\'), DIRECTORY_SEPARATOR, $uploaddir);
				
			// Check if user has added file
			if ($_FILES['editor']['size']['settings']['background_tile'] != 0 ) {
					
				// Create directory if not exists
				if (!is_dir($uploaddir)) {
					@mkdir($uploaddir, 0777, true);
				}
				// Picture name
				//$ext = findExtension($_FILES['new_card']['name']['picture_link']);
				$picturename =  $_SESSION['admin']['game']['name'] . '_tile_' . $background_tile;
				$picture = generateFilename($picturename, $uploaddir);
				$uploadfile2 = $uploaddir . $picture;
				$background_tile = $picture;
				if (!move_uploaded_file($_FILES['editor']['tmp_name']['settings']['background_tile'], $uploadfile2)) {
    				$background_tile = '';
				}
			}
			
			unset($_POST['editor']['settings']['background_tile']);
			unset($_POST['change_background_tile']);
			
			if (isset($_SESSION['admin']['game']['game_id'])) {
				
				$_SESSION['admin']['game']['background_tile'] = $background_tile;
				$game = $_SESSION['admin']['game'];
				$db = DB::getInstance();
				$db->updateGame($game);
			}
			$_POST['notifications'] = array();
			$_POST['notifications']['background_tile_changed'] = true;
		}
		else {
			$_POST['notifications'] = array();
			$_POST['notifications']['background_tile_changed'] = false;
		}
	}
	
	// Change game logo form is submitted
	if (isset($_POST['change_logo'])) {
		
		//exit(print_r($_FILES));
		if (isset($_POST['notifications'])) {
			unset($_POST['notifications']);
		}
		$form_data['editor'] = array();
		$form_errors['editor']['settings'] = array();
		
		if (isset($_FILES['editor']['name']['settings']['logo']) && !empty($_FILES['editor']['name']['settings']['logo'])) {

			$file_name = $form_handler->SanitizeString($_FILES['editor']['name']['settings']['logo']);
			
			if (!$file_name) {
				$error = true;
				$form_errors['editor']['settings']['logo'] = $form_handler->_latest_error;
			}
			else {		
				// Check that logo isn't too big
				if ($_FILES['editor']['size']['settings']['logo'] > CARD_ATTACHMENT_MAX_SIZE) {
					$error = true;
					$form_errors['editor']['settings']['logo'] = localize("ERROR_FORM_HANDLER_FILE_MAX_SIZE");
				}
				if (!$error) {
					$form_data['settings']['logo'] = $file_name;
				}
			}
		}
		else {
			$form_data['settings']['logo'] = '';
			if (isset($_POST['editor']['settings']['logo_text_hidden'])) {
				$form_data['settings']['logo'] = $_POST['editor']['settings']['logo_text_hidden'];
			}
		}
		// If form is valid
		if (!$error) {
			
			$logo = $form_data['settings']['logo'];
				
			global $image_folder;
			$uploaddir = '..' . DIRECTORY_SEPARATOR . $image_folder;
				
			if (!empty($_SESSION['admin']['game']['image_folder'])) {
				$uploaddir = '..' . DIRECTORY_SEPARATOR . $_SESSION['admin']['game']['image_folder'];
			}
			$uploaddir = str_replace(array('/', '\\'), DIRECTORY_SEPARATOR, $uploaddir);
				
			// Check if user has added file
			if ($_FILES['editor']['size']['settings']['logo'] != 0 ) {
					
				// Create directory if not exists
				if (!is_dir($uploaddir)) {
					@mkdir($uploaddir, 0777, true);
				}
				// Picture name
				//$ext = findExtension($_FILES['new_card']['name']['picture_link']);
				$picturename =  $_SESSION['admin']['game']['name'] . '_logo_' . $logo;
				$picture = generateFilename($picturename, $uploaddir);
				$uploadfile2 = $uploaddir . $picture;
				$logo = $picture;
				if (!move_uploaded_file($_FILES['editor']['tmp_name']['settings']['logo'], $uploadfile2)) {
    				$logo = '';
				}
			}
			
			unset($_POST['editor']['settings']['logo']);
			unset($_POST['change_logo']);
			
			if (isset($_SESSION['admin']['game']['game_id'])) {
				
				$_SESSION['admin']['game']['logo'] = $logo;
				$game = $_SESSION['admin']['game'];
				$db = DB::getInstance();
				$db->updateGame($game);
			}
			$_POST['notifications'] = array();
			$_POST['notifications']['logo_changed'] = true;
		}
		else {
			$_POST['notifications'] = array();
			$_POST['notifications']['logo_changed'] = false;
		}
	}
	
	// Change image folder form is submitted
	if (isset($_POST['change_image_folder'])) {
		
		if (isset($_SESSION['editor']['settings']['new_password'])) {
			unset($_SESSION['editor']['settings']['new_password']);
		}
		if (isset($_POST['notifications'])) {
			unset($_POST['notifications']);
		}
		$form_data['editor'] = array();
		$form_errors['editor']['settings'] = array();
		
		if (isset($_POST['editor']['settings']['image_folder'])) {
			
			if (empty($_POST['editor']['settings']['image_folder'])) {
				$form_data['settings']['image_folder'] = $_POST['editor']['settings']['image_folder'];
			}
			else {
			
				$data = $form_handler->SanitizeString($_POST['editor']['settings']['image_folder']);
				
				if (!$data) {
					$error = true;
					$form_errors['editor']['settings']['image_folder'] = $form_handler->_latest_error;
				}
				else {
					$folder = str_replace('\\', '/', $data);
					$image_path = dirname(__FILE__) . '/../' . $folder;
					// If folder doesn't exist create one
					if (!is_dir($image_path)) {
			
						if (!mkdir($image_path, 0777, true)) {
							$error = true;
							$form_errors['editor']['settings']['image_folder'] = localize('ERROR_CANT_CREATE_DIRECTORY');
						}
					}
					$form_data['settings']['image_folder'] = $data;
				}
			}
		}
		// If form is valid
		if (!$error) {
			
			unset($_POST['editor']['settings']['image_folder']);
			unset($_POST['change_image_folder']);
			
			if (isset($_SESSION['admin']['game']['game_id'])) {
				
				global $image_folder;
				// If default image folder is set then store empty string to db
				if ($form_data['settings']['image_folder'] == $image_folder) {
					$form_data['settings']['image_folder'] = '';
				}
				$_SESSION['admin']['game']['image_folder'] = $form_data['settings']['image_folder'];
				$game = $_SESSION['admin']['game'];
				$db = DB::getInstance();
				$db->updateGame($game);
			}
			$_POST['notifications'] = array();
			$_POST['notifications']['image_folder_changed'] = true;
		}
		else {
			$_POST['notifications'] = array();
			$_POST['notifications']['image_folder_changed'] = false;
		}
	}
	
	// Change game slug is submitted
	if (isset($_POST['change_slug'])) {
		
		if (isset($_POST['notifications'])) {
			unset($_POST['notifications']);
		}
		$form_data['editor'] = array();
		$form_errors['editor']['settings'] = array();
		
		if (isset($_POST['editor']['settings']['slug'])) {
			
			$data = $form_handler->SanitizeString($_POST['editor']['settings']['slug']);
				
			if (!$data) {
				$error = true;
				$form_errors['editor']['settings']['slug'] = $form_handler->_latest_error;
			}
			else {
				
				$form_data['settings']['slug'] = $data;
			}
		}
		// If form is valid
		if (!$error) {
			
			unset($_POST['editor']['settings']['slug']);
			unset($_POST['change_slug']);
			
			if (isset($_SESSION['admin']['game']['game_id'])) {
				
				$db = DB::getInstance();
				$game = $db->getGame($_SESSION['admin']['game']['game_id']);
				$game['slug'] = $form_data['settings']['slug'];
				$db->updateGame($game);
				$_SESSION['admin']['game'] = $db->getGame($_SESSION['admin']['game']['game_id']);
			}
			$_POST['notifications'] = array();
			$_POST['notifications']['slug_changed'] = true;
		}
		else {
			$_POST['notifications'] = array();
			$_POST['notifications']['slug_changed'] = false;
		}
	}
	
	// Change password form is submitted
	if (isset($_POST['change_password'])) {
		
		if (isset($_SESSION['editor']['settings']['image_folder'])) {
			unset($_SESSION['editor']['settings']['image_folder']);
		}
		if (isset($_POST['notifications'])) {
			unset($_POST['notifications']);
		}
		$form_data['editor'] = array();
		$form_errors['editor']['settings'] = array();
		
		if (isset($_POST['editor']['settings']['new_password'])) {
			
			$data = $form_handler->SanitizeString($_POST['editor']['settings']['new_password'], PASSWORD_MAX_LENGTH, false);
			
			if (!$data) {
				$error = true;
				$form_errors['editor']['settings']['new_password'] = $form_handler->_latest_error;
			}
			else {
				$form_data['settings']['new_password'] = $data;
			}
		}
		if (isset($_POST['editor']['settings']['new_password2'])) {
			
			$data = $form_handler->SanitizeString($_POST['editor']['settings']['new_password2'], PASSWORD_MAX_LENGTH, false);
			
			if (!$data) {
				$error = true;
				$form_errors['editor']['settings']['new_password2'] = $form_handler->_latest_error;
			}
			else {
				$form_data['settings']['new_password2'] = $data;
			}
		}
		if (!$error && isset($form_data['settings']['new_password']) && isset($form_data['settings']['new_password2'])) {
			
			if ($form_data['settings']['new_password'] !== $form_data['settings']['new_password2']) {
				$error = true;
				$form_errors['editor']['settings']['new_password2'] = localize('ERROR_FORM_HANDLER_PASSWORD_MATCH');
			}
		}
		if (isset($_POST['editor']['settings']['current_password'])) {
			
			$data = $form_handler->SanitizeString($_POST['editor']['settings']['current_password'], PASSWORD_MAX_LENGTH, false);
			
			if (!$data) {
				$error = true;
				$form_errors['editor']['settings']['current_password'] = $form_handler->_latest_error;
			}
			else {
				$form_data['settings']['current_password'] = $data;
				
				if (isset($_SESSION['user']['username'])) {
					$db = DB::getInstance();
					// Try to change the password
					if (!$db->changePassword($_SESSION['user']['username'], $form_data['settings']['current_password'], $form_data['settings']['new_password'])) {
						$error = true;
						$form_errors['editor']['settings']['current_password'] = localize('ERROR_ADMIN_EDITOR_PASSWORD');
					}
				}
				else {
					$error = true;
				}
			}
		}
		// If form is valid
		if (!$error) {
			unset($_POST['editor']['settings']['new_password']);
			unset($_POST['editor']['settings']['new_password2']);
			unset($_POST['editor']['settings']['current_password']);
			unset($_POST['change_password']);
			$_POST['notifications'] = array();
			$_POST['notifications']['password_changed'] = true;
		}
		else {
			$_POST['notifications'] = array();
			$_POST['notifications']['password_changed'] = false;
		}
	}
	// Modify admin rights form is submitted
	if (isset($_POST['change_admins'])) {

		if (isset($_SESSION['editor']['settings']['image_folder'])) {
			unset($_SESSION['editor']['settings']['image_folder']);
		}
		if (isset($_SESSION['editor']['settings']['new_password'])) {
			unset($_SESSION['editor']['settings']['new_password']);
		}
		if (isset($_POST['notifications'])) {
			unset($_POST['notifications']);
		}
		$form_data['editor'] = array();
		$form_errors['editor']['settings'] = array();
		
		if (isset($_POST['user_list_admins'])) {
			
			$new_admins = $_POST['user_list_admins'];
			if (empty($new_admins)) {
				// Game must have atleast one admin
				$error = true;
				$form_errors['editor']['settings']['user_list'] = localize("ERROR_ADMIN_EDITOR_ADMINS");
			}
			else {
				
				if (in_array($_SESSION['admin']['game']['main_admin_id'], $new_admins)) {
					$form_data['settings']['admins'] = $new_admins;
				}
				else {
					// Main admin can't be removed
					$error = true;
					$form_errors['editor']['settings']['user_list'] = localize("ERROR_ADMIN_EDITOR_MAIN_ADMIN");
				}
			}
		}
		// Game must have atleast one admin
		else {
			$error = true;
			$form_errors['editor']['settings']['user_list'] = localize("ERROR_ADMIN_EDITOR_ADMINS");
		}
		
		// If form is valid
		if (!$error) {
			
			if (isset($_SESSION['admin']['game']['game_id'])) {
				
				$game_id = $_SESSION['admin']['game']['game_id'];
				$new_admins = $form_data['settings']['admins'];
				$db = DB::getInstance();
				$old_admins = $db->getAdminIDs($game_id);
				
				// Remove admin rights
				foreach ($old_admins as $admin) {
					if (!in_array($admin, $new_admins)) {
						$db->removeAdmin($admin, $game_id);
					}
				}
				// Add new admin rights
				foreach ($new_admins as $admin) {
					if (!in_array($admin, $old_admins)) {
						$db->addAdmin($admin, $game_id);
					}
				}
				unset($_POST['change_admins']);
				unset($form_errors['editor']['settings']);
				$_POST['notifications'] = array();
				$_POST['notifications']['admin_rights_changed'] = true;
			}
		}
		else {
			$_POST['notifications'] = array();
			$_POST['notifications']['admin_rights_changed'] = false;
		}
	}
	// Change game settings form isset (submit button)
	elseif (isset($_POST['change_game_settings'])) {

		if (isset($_SESSION['editor']['settings']['image_folder'])) {
			unset($_SESSION['editor']['settings']['image_folder']);
		}
		if (isset($_SESSION['editor']['settings']['new_password'])) {
			unset($_SESSION['editor']['settings']['new_password']);
		}
		if (isset($_POST['notifications'])) {
			unset($_POST['notifications']);
		}
		$form_data['editor'] = array();
		$form_errors['editor']['settings'] = array();
		
		if (isset($_POST['editor']['settings']['tags'])) {
			
			if (intval($_POST['editor']['settings']['tags'])) {
				$form_data['settings']['use_tags'] = 1;
			}
			else {
				$form_data['settings']['use_tags'] = 0;
			}
		}
		if (isset($_POST['editor']['settings']['stats'])) {
			
			if (intval($_POST['editor']['settings']['stats'])) {
				$form_data['settings']['use_stats'] = 1;
			}
			else {
				$form_data['settings']['use_stats'] = 0;
			}
		}
		if (isset($_POST['editor']['settings']['expert_advice'])) {
			
			if (intval($_POST['editor']['settings']['expert_advice'])) {
				$form_data['settings']['use_expert_advice'] = 1;
			}
			else {
				$form_data['settings']['use_expert_advice'] = 0;
			}
		}
		if (isset($_POST['editor']['settings']['sudden_scenarios'])) {
			
			if (intval($_POST['editor']['settings']['sudden_scenarios'])) {
				$form_data['settings']['use_sudden_scenarios'] = 1;
			}
			else {
				$form_data['settings']['use_sudden_scenarios'] = 0;
			}
		}
		if (isset($_POST['editor']['settings']['ending_criteria'])) {
			
			if (intval($_POST['editor']['settings']['ending_criteria'])) {
				$form_data['settings']['use_ending_criteria'] = 1;
			}
			else {
				$form_data['settings']['use_ending_criteria'] = 0;
			}
		}
		if (isset($_POST['editor']['settings']['use_login'])) {
			
			if (intval($_POST['editor']['settings']['use_login'])) {
				$form_data['settings']['use_login'] = 1;
			}
			else {
				$form_data['settings']['use_login'] = 0;
			}
		}
		if (isset($_POST['editor']['settings']['use_name'])) {
			
			if (intval($_POST['editor']['settings']['use_name'])) {
				$form_data['settings']['use_name'] = 1;
			}
			else {
				$form_data['settings']['use_name'] = 0;
			}
		}
		if (isset($_POST['editor']['settings']['multiple_languages'])) {
			
			if (intval($_POST['editor']['settings']['multiple_languages'])) {
				$form_data['settings']['multiple_languages'] = 1;
			}
			else {
				$form_data['settings']['multiple_languages'] = 0;
			}
		}
		if (isset($_POST['editor']['settings']['show_cards_ending'])) {
			
			if (intval($_POST['editor']['settings']['show_cards_ending'])) {
				$form_data['settings']['show_cards_ending'] = 1;
			}
			else {
				$form_data['settings']['show_cards_ending'] = 0;
			}
		}
		if (isset($_POST['editor']['settings']['sudden_scenarios_definitions'])) {
			
			$scenario_counter = 0;
			$scenarios = array();
			
			foreach ($_POST['editor']['settings']['sudden_scenarios_definitions'] as $sudden_scenario) {

				$empty_scenario = true;
				// If all fields are empty don't add scenario
				if (!empty($sudden_scenario['odds'])) {
					$empty_scenario = false;
				}
				if (!empty($sudden_scenario['result'])) {
					$empty_scenario = false;
				}
				
				$condition_counter = 0;
				$conditions_array = array();

				foreach ($sudden_scenario['conditions'] as $condition) {
					
					// If all fields are empty don't add condition
					$empty_condition = true;
					if (!empty($condition['condition_text'])) {
						$empty_condition = false;
						$empty_scenario = false;
					}
					if (!empty($condition['condition_logic'])) {
						$empty_condition = false;
						$empty_scenario = false;
					}
					// If scenario values are not empty but condition isn't set and this isn't first
					// condition then skip
					if (!$empty_scenario && $empty_condition && ($condition_counter != 0)) {
						$condition_counter++;
						continue;
					}
					//TODO: add more validations
					// If scenario values are empty and condition values are empty then skip
					elseif ($empty_scenario && $empty_condition) {
						$condition_counter++;
						continue;
					}
					else {
						
						$new_condition = array();
						$data = $form_handler->SanitizeString($condition['condition_text']);
						if (!$data) {
							$error = true;
							$form_errors['editor']['settings']['sudden_scenarios_definitions'][$scenario_counter]['conditions'][$condition_counter]['condition_text'] = $form_handler->_latest_error;
						}
						else {
							//$form_data['new_card']['choices'][$choice_counter]['text'] = $data;
							$new_condition['condition_text'] = $data;
							$new_condition['condition_logic'] = '';
							if (isset($condition['condition_logic'])) {
								$new_condition['condition_logic'] = $condition['condition_logic'];
							}
							$conditions_array[] = $new_condition;
						}
					}
					$condition_counter++;
				}
				if ($empty_scenario) {
					$scenario_counter++;
					continue;
				}
				else {
					$new_scenario = array();
					$data = $form_handler->ValidateInt($sudden_scenario['odds']);
			
					if (!$data) {
						$error = true;
						$form_errors['editor']['settings']['sudden_scenarios_definitions'][$scenario_counter]['odds'] = $form_handler->_latest_error;
					}
					else {
						if ($data > 0 && $data <= 100) {
							$new_scenario['odds'] = $data;
						}
						else {
							$error = true;
							// TODO: Validate sum of sudden scenario percentages
							$form_errors['editor']['settings']['sudden_scenarios_definitions'][$scenario_counter]['odds'] = localize("ERROR_ADMIN_EDITOR_ODDS_PERCENT");
						}
					}
					$data = $form_handler->SanitizeString($sudden_scenario['result']);
			
					if (!$data) {
						$error = true;
						$form_errors['editor']['settings']['sudden_scenarios_definitions'][$scenario_counter]['result'] = $form_handler->_latest_error;
					}
					else {
						$new_scenario['result'] = $data;
					}
					if (!$error) {
						// set ordinals
						$ord_counter = 1;
						foreach ($conditions_array as &$cond) {
							$cond['ordinal'] = $ord_counter;
							$ord_counter++;
						}
						$new_scenario['conditions'] = $conditions_array;
						$scenarios[] = $new_scenario; 
					}
				}
				$scenario_counter++;
			}
			if (!$error && !empty($scenarios)) {
				// set ordinals
				$scen_counter = 1;
				foreach ($scenarios as &$scen) {
					$scen['ordinal'] = $scen_counter;
					$scen_counter++;
				}
				$form_data['settings']['sudden_scenarios'] = $scenarios;
			}
		}
		
		if (isset($_POST['editor']['settings']['ending_criteria_definitions'])) {
			
			$criteria_counter = 0;
			$criterias = array();
			
			foreach ($_POST['editor']['settings']['ending_criteria_definitions'] as $ending_criteria) {

				$empty_criteria = true;
				// If all fields are empty don't add criteria
				if (!empty($ending_criteria['result'])) {
					$empty_criteria = false;
				}
				
				$condition_counter = 0;
				$conditions_array = array();

				foreach ($ending_criteria['conditions'] as $condition) {
					
					// If all fields are empty don't add condition
					$empty_condition = true;
					if (!empty($condition['condition_text'])) {
						$empty_condition = false;
						$empty_criteria = false;
					}
					if (!empty($condition['condition_logic'])) {
						$empty_condition = false;
						$empty_criteria = false;
					}
					// If criteria values are not empty but condition isn't set and this isn't first
					// condition then skip
					if (!$empty_criteria && $empty_condition && ($condition_counter != 0)) {
						$condition_counter++;
						continue;
					}
					//TODO: add more validations
					// If criteria values are empty and condition values are empty then skip
					elseif ($empty_criteria && $empty_condition) {
						$condition_counter++;
						continue;
					}
					else {
						
						$new_condition = array();
						$data = $form_handler->SanitizeString($condition['condition_text']);
						
						if (!$data) {
							$error = true;
							$form_errors['editor']['settings']['ending_criteria_definitions'][$criteria_counter]['conditions'][$condition_counter]['condition_text'] = $form_handler->_latest_error;
						}
						else {
							//$form_data['new_card']['choices'][$choice_counter]['text'] = $data;
							$new_condition['condition_text'] = $data;
							$new_condition['condition_logic'] = '';
							if (isset($condition['condition_logic'])) {
								$new_condition['condition_logic'] = $condition['condition_logic'];
							}
							$conditions_array[] = $new_condition;
						}
					}
					$condition_counter++;
				}
				if ($empty_criteria) {
					$criteria_counter++;
					continue;
				}
				else {
					$new_criteria = array();
					$data = $form_handler->SanitizeString($ending_criteria['result']);
			
					if (!$data) {
						$error = true;
						$form_errors['editor']['settings']['ending_criteria_definitions'][$criteria_counter]['result'] = $form_handler->_latest_error;
					}
					else {
						$new_criteria['result'] = $data;
					}
					if (!$error) {
						// set ordinals
						$ord_counter = 1;
						foreach ($conditions_array as &$cond) {
							$cond['ordinal'] = $ord_counter;
							$ord_counter++;
						}
						$new_criteria['conditions'] = $conditions_array;
						$criterias[] = $new_criteria; 
					}
				}
				$criteria_counter++;
			}
			if (!$error && !empty($criterias)) {
				// set ordinals
				$crit_counter = 1;
				foreach ($criterias as &$crit) {
					$crit['ordinal'] = $crit_counter;
					$crit_counter++;
				}
				$form_data['settings']['ending_criteria'] = $criterias;
			}
		}
		$db = DB::getInstance();
		$cards = $db->getAllCards($_SESSION['admin']['game']['game_id'], 'en-US');
		
		if (isset($_POST['editor']['settings']['panic_card'])) {
			
			$data = $form_handler->ValidateInt($_POST['editor']['settings']['panic_card']);
			
			if (!$data && ($_POST['editor']['settings']['panic_card'] !== '0')) {
				$error = true;
				$form_errors['editor']['settings']['panic_card'] = $form_handler->_latest_error;
				exit($form_errors['editor']['settings']['panic_card']);
			}
			else {
				if (doubleval($data) < 1) {
					$form_data['settings']['panic_card_id'] = 0;
				}
				else {
					$actual_panic_card = 0;
					// Check panic cards actual id
					foreach($cards as $card) {
					
						if ($card['card_external_id'] == $data) {
							$actual_panic_card = $card['card_id'];
							break;
						}
					}
					unset($card);
					if ($actual_panic_card > 0) {
						$form_data['settings']['panic_card_id'] = $actual_panic_card;
					}
					else {
						$form_errors['editor']['settings']['panic_card'] = localize("CARD_NOT_FOUND");
						$error = true;
					}
				}
			}
		}
		
		if (isset($_POST['editor']['settings']['starting_card'])) {
			
			$data = $form_handler->ValidateInt($_POST['editor']['settings']['starting_card']);
			
			if (!$data && ($_POST['editor']['settings']['starting_card'] !== '0')) {
				$error = true;
				$form_errors['editor']['settings']['starting_card'] = $form_handler->_latest_error;
			}
			else {
				if (doubleval($data) < 1) {
					$form_data['settings']['starting_card_id'] = 0;
				}
				else {
					$actual_starting_card = $data;
					
					if ($actual_starting_card > 0) {
						$form_data['settings']['starting_card_id'] = $actual_starting_card;
					}
					else {
						$error = true;
						$form_errors['editor']['settings']['starting_card'] = localize("CARD_NOT_FOUND");
					}
				}
			}
		}
		
		if (isset($_POST['editor']['settings']['max_cancellations'])) {

			$data = $form_handler->ValidateInt($_POST['editor']['settings']['max_cancellations']);
			
			if (!$data && ($_POST['editor']['settings']['max_cancellations'] !== '0')) {
				$error = true;
				$form_errors['editor']['settings']['max_cancellations'] = $form_handler->_latest_error;
			}
			else {
				if (intval($data) == 0) {
					$form_data['settings']['max_cancellations'] = 0;
				}
				elseif (intval($data) < 0) {
					$form_data['settings']['max_cancellations'] = -1;
				}
				else {
					$form_data['settings']['max_cancellations'] = $data;
				}
			}
		}
		// If form is valid
		if (!$error) {
			
			unset($_POST['editor']['settings']);
			unset($_POST['change_game_settings']);
			
			$_SESSION['admin']['game']['use_tags'] = $form_data['settings']['use_tags'];
			$_SESSION['admin']['game']['use_stats'] = $form_data['settings']['use_stats'];
			$_SESSION['admin']['game']['use_expert_advice'] = $form_data['settings']['use_expert_advice'];
			$_SESSION['admin']['game']['use_sudden_scenarios'] = $form_data['settings']['use_sudden_scenarios'];
			$_SESSION['admin']['game']['use_ending_criteria'] = $form_data['settings']['use_ending_criteria'];
			$_SESSION['admin']['game']['use_login'] = $form_data['settings']['use_login'];
			$_SESSION['admin']['game']['use_name'] = $form_data['settings']['use_name'];
			$_SESSION['admin']['game']['multiple_languages'] = $form_data['settings']['multiple_languages'];
			$_SESSION['admin']['game']['show_cards_ending'] = $form_data['settings']['show_cards_ending'];
			$_SESSION['admin']['game']['panic_card_id'] = $form_data['settings']['panic_card_id'];
			$_SESSION['admin']['game']['starting_card_id'] = $form_data['settings']['starting_card_id'];
			$_SESSION['admin']['game']['max_cancellations'] = $form_data['settings']['max_cancellations'];
			
			if (isset($form_data['settings']['sudden_scenarios'])) {
				$_SESSION['admin']['game']['sudden_scenarios'] = $form_data['settings']['sudden_scenarios'];
			}
			if (isset($form_data['settings']['ending_criteria'])) {
				$_SESSION['admin']['game']['ending_criteria'] = $form_data['settings']['ending_criteria'];
			}
			if (isset($_SESSION['admin']['game']['game_id'])) {
				$game = $_SESSION['admin']['game'];
				$db = DB::getInstance();
				$db->updateGame($game);
			}
			$_POST['notifications'] = array();
			$_POST['notifications']['game_settings_changed'] = true;
		}
		else {
			$_POST['notifications'] = array();
			$_POST['notifications']['game_settings_changed'] = false;
		}
	}
	
	// Update texts form is submitted
	if (isset($_POST['admin_editor_form_update_texts']) || isset($_POST['admin_editor_form_texts_add_translation']) || isset($_POST['admin_editor_form_texts_select_translation'])) {
		
		$form_data['texts'] = array();
		
		if (isset($_POST['admin']['settings']['texts'])) {
			
			foreach ($_POST['admin']['settings']['texts'] as $key => $value) {
				
				$form_data['texts'][$key] = htmlspecialchars($value, ENT_COMPAT, 'UTF-8');
			}
		}
		
		if (isset($_POST['admin_editor_form_texts_add_translation']) && isset($form_data['texts']['add_translation'])) {
			if (!isset($form_data['texts']['default_lang']) || empty($form_data['texts']['default_lang'])) {
				$form_data['texts']['default_lang'] = $form_data['texts']['add_translation'];
			}
		
			if (isset($form_data['texts']['translations']) || empty($form_data['texts']['translations'])) {
				$form_data['texts']['translations'] = $form_data['texts']['add_translation'];
			}
		}
		
		// If form is valid && user is super admin
		if (!$error) {

			if (isset($_SESSION['admin']['game']['game_id']) && isset($_SESSION['user']['user_id']) && !empty($form_data['texts']) && isset($form_data['texts']['translations']) && isset($form_data['texts']['default_lang'])) {
				
				$game_id = $_SESSION['admin']['game']['game_id'];
				$default_lang = $form_data['texts']['default_lang'];
				$current_translation = $form_data['texts']['current_translation'];
				
				if (isset($_POST['admin_editor_form_texts_select_translation'])) {
					$current_translation = $form_data['texts']['translations'];
				}
				else {
				
					// If user is clicked add new translation current translation is the one to add
					if (isset($form_data['texts']['add_translation']) && !empty($form_data['texts']['add_translation'])) {
						$current_translation = $form_data['texts']['add_translation'];
					}
					
					$is_default = 1;
					if ($default_lang != $current_translation) {
						$is_default = 0;
					}
					$db = DB::getInstance();
					// Add new translation or update old one
					$db->addOrUpdateGameTexts($game_id, $form_data['texts'], $current_translation, $is_default, $default_lang);
				}
				unset($_POST['admin']['settings']['texts']);
				unset($form_errors);
				
				$_POST['notifications'] = array();
				if (isset($_POST['admin_editor_form_update_texts'])) {
					$_POST['notifications']['game_texts']['updated'] = true;
					$_POST['game_text_translation_lang'] = $current_translation;
					unset($_POST['admin_editor_form_update_texts']);
				}
				elseif (isset($_POST['admin_editor_form_texts_add_translation'])) {
					$_POST['notifications']['game_texts']['translation_added'] = true;
					$_POST['game_text_translation_lang'] = $current_translation;
					unset($_POST['admin_editor_form_texts_add_translation']);
				}
				elseif (isset($_POST['admin_editor_form_texts_select_translation'])) {
					$_POST['notifications']['game_texts']['switch'] = true;
					$_POST['game_text_translation_lang'] = $current_translation;
					unset($_POST['admin_editor_form_texts_select_translation']);
				}
			}
			else {
				$_POST['notifications'] = array();
			if (isset($_POST['admin_editor_form_update_texts'])) {
					$_POST['notifications']['game_texts']['updated'] = false;
				}
				elseif (isset($_POST['admin_editor_form_texts_add_translation'])) {
					$_POST['notifications']['game_texts']['translation_added'] = false;
				}
			}
		}
	}
	
	// Change visible stats is submitted
	if (isset($_POST['change_visible_stats'])) {
		
		if (isset($_POST['notifications'])) {
			unset($_POST['notifications']);
		}
		$form_data['editor'] = array();
		$form_errors['editor']['settings'] = array();
		
		if (isset($_POST['editor']['settings']['visible_stats'])) {
			
			$_POST['editor']['settings']['visible_stats'] = trim($_POST['editor']['settings']['visible_stats']);
			$data = $form_handler->SanitizeString($_POST['editor']['settings']['visible_stats']);
			
			if (!$data && $_POST['editor']['settings']['visible_stats'] != '') {

				$error = true;
				$form_errors['editor']['settings']['visible_stats'] = $form_handler->_latest_error;
			}
			else {
	
				$data_array = explode('@', $data);
				$stats = array();
				
				foreach ($data_array as $stat) {
					$trimmed = trim($stat);
					if (!empty($trimmed)) {
						$stats[] = $trimmed;
					}
				}
				$form_data['settings']['visible_stats'] = $stats;
			}
		}
		// If form is valid
		if (!$error) {

			unset($_POST['editor']['settings']['visible_stats']);
			unset($_POST['change_visible_stats']);
			
			if (isset($form_data['settings']['visible_stats']) && isset($_SESSION['admin']['game']['game_id'])) {

				$_SESSION['admin']['game']['visible_stats'] = $form_data['settings']['visible_stats'];
				$game = $_SESSION['admin']['game'];
				$db = DB::getInstance();
				$db->updateGame($game);
				
							
				$_POST['notifications'] = array();
				$_POST['notifications']['visible_stats_changed'] = true;
			}
			else {

				$_POST['notifications'] = array();
				$_POST['notifications']['visible_stats_changed'] = false;
			}
		}				
	}
	
	// Delete game form is submitted
	if (isset($_POST['delete_game_modal_yes_button'])) {
		
		$game_id = 0;
		
		if (isset($_POST['admin']['delete_game']['game_id'])) {
			$game_id = doubleval($_POST['admin']['delete_game']['game_id']);
		}
		$db = DB::getInstance();
		
		if ($db->deleteGame($game_id)) {
			unset($_SESSION['admin']['game']);
			header("Location: index.php?game_deleted=true");
			exit;
		}
		else {
			// TODO: Error
		}
	}
	
	// If import csv file form is submitted
	if (isset($_POST['import_csv_file'])) {
		
		$form_errors['editor']['import'] = array();
		
		if (isset($_FILES['csv_file']['name']) && !empty($_FILES['csv_file']['name'])) {
		
			$file = $_FILES['csv_file']['tmp_name'];
			$contents = '';
			
			$cards = get_cards_from_csv($file);
		
			if (isset($_SESSION['admin']['game']['game_id']) && isset($_SESSION['user']['user_id'])) {
				
				$game_id = $_SESSION['admin']['game']['game_id'];
				$creator_id = $_SESSION['user']['user_id'];
				global $default_language;
				$lang = $default_language;
				$db = DB::getInstance();
				
				
				foreach ($cards as $card) {
					
					if ($card['card_external_id'] == 0) {
						$card['card_external_id'] = $_SESSION['admin']['game']['latest_card_id'] + 1;
						$_SESSION['admin']['game']['latest_card_id'] = $card['card_external_id'];
					}
					else {
						if ($card['card_external_id'] > $_SESSION['admin']['game']['latest_card_id']) {
							$_SESSION['admin']['game']['latest_card_id'] = $card['card_external_id'];
						}
					}
					$db->importCard($card['card_external_id'], $card['repetitive'], $card['tags'], $card['stats'], $card['comment'], $card['attachment'], $card['card_name'], $card['description'], $card['expert_advice'], $card['choices'], $card['results'], $game_id, $lang, $creator_id);
				}
				
				unset($_POST['import_csv_file']);
				$_POST['notifications'] = array();
				$_POST['notifications']['cards_imported'] = true;
			}	
		}
	}
}