<?php
/**
*	@file admin_functions.php
*	@brief Contains functions that are related to administator view.
*/
require_once(dirname(__FILE__) . '/../general/functions.php');
require_once(dirname(__FILE__) . '/admin_index_form_handling.php');
require_once(dirname(__FILE__) . '/admin_editor_form_handling.php');
require_once(dirname(__FILE__) . '/../libs/forceutf8/Encoding.php');

/**
* Function to print out admin HTML-page start with given title.
* @param string $title_code represents corresponding translation of a page title. Empty string by default.
* @return void
*/
function print_admin_html_start($title_code='') {
	
	$title = '';
	if (empty($title_code)) {
		global $default_title;
		$title = $default_title;
	}
	else {
		$title = localize($title_code);
	}
?>	
<!DOCTYPE html>
<html>
<head>
<meta charset="UTF-8">
<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
<script type="text/javascript" src="../js/jquery-1.8.3.min.js"></script>
<script type="text/javascript" src="../js/jquery.scrollTo-1.4.3.1-min.js"></script>
<script type="text/javascript" src="../js/jqModal.js"></script>
<script type="text/javascript" src="../js/jquery-ui-1.10.3.custom.min.js"></script>
<script type="text/javascript" src="../js/jquery.ui.touch-punch.min.js"></script>
<script type="text/javascript" src="../js/jquery.tablesorter.min.js"></script>
<script type="text/javascript" src="../js/jquery.sticky.js"></script>
<script type="text/javascript" src="../js/jscolor/jscolor.js"></script>
<script type="text/javascript" src="../js/admin.js"></script>
<script type="text/javascript" src="../js/main.js"></script>
<link rel="stylesheet" type="text/css" href="../css/main.css" />
<link rel="stylesheet" type="text/css" href="../css/admin.css" />
<link rel="stylesheet" type="text/css" href="../css/jqModal.css" />
<link rel="stylesheet" href="../css/jquery-ui/smoothness/jquery-ui-1.10.3.custom.min.css" />
<title><?php echo $title; ?></title>
</head>
<body>
<script type="text/javascript">
<?php $config = Config::getInstance();
		echo ('window.baseurl = "' . $config->baseurl . '";' . PHP_EOL);
		echo("window.modRewrite = ");
		if (modRewriteEnabled()) {
			echo("true;");
		}
		else {
			echo("false;");
		}
?>
</script>
<?php
}

/**
* Function to print out current game name.
* Gets name from $_SESSION['admin']['game']['name'].
* @return void
*/
function print_admin_game_name() {

	$game_name = '';
	
	if (isset($_SESSION['admin']['game']['name'])) {
		$game_name = $_SESSION['admin']['game']['name'];
	}
	$config = Config::getInstance();
?>
		<?php if (!empty($game_name)) {
					//echo('<a href="' . formatAppLink($config->baseurl . 'game/' . $_SESSION['admin']['game']['slug']) . '">' . $game_name . '</a>');
					echo('<a href="' . formatAppLink($config->baseurl . 'app/index.php?game_slug=' . $_SESSION['admin']['game']['slug']) . '">' . $game_name . '</a>');
				}
		?>
<?php
}

/**
* Function to print out game login information.
* Gets those from $_SESSION['user']['username'] and $_SESSION['isLogged'].
* @return void
*/
function print_admin_login() {
	
	$username = '';
	if (isset($_SESSION['user']['username'])) {
		$username = $_SESSION['user']['username'];
	}
	$isLogged = false;
	if (isset($_SESSION['isLogged']) && $_SESSION['isLogged']) {
		$isLogged = true;
	}
?>
		<?php if (!empty($username)) :?>
			<a class="jqModal" id="user_settings_button" href="#"><?php echo($username); ?></a><br />
		<?php endif; ?>
		<?php if ($isLogged) :?>
			<a href="../general/logout.php?admin=true"><?php echo localize("LOGOUT"); ?></a><br />
		<?php else: ?>
		<?php 	if (!empty($username)) :?>
			<a href="../general/logout.php?admin=true"><?php echo localize("QUIT"); ?></a>
		<?php 	endif;?>
		<?php endif; ?>
<?php
}

/**
* Function to print out admin language bar.
* @param string $active_lang tells which language is active. Default is an empty string.
* @return void
*/
function print_language_bar_admin($active_lang='') {

	global $languages;
	$counter = 0;
	foreach ($languages as $lang) {
		if ($counter > 0) {
			echo(' | ');
		}
		$counter++;
		// Get the correct language abbreviation
		$lang_file = LOCALE_PATH . $lang . '.txt';
		$lang_file_content = file_get_contents($lang_file, FILE_USE_INCLUDE_PATH);
		/* Load the language file as a JSON object and transform it into an associative array */
		$texts = json_decode($lang_file_content, true);
		$abbreviation = $texts['LANG_ABBREVIATION'];

		if ($active_lang != $lang) { ?>
	<a href="<?php echo($_SERVER['PHP_SELF']); ?>?lang=<?php echo $lang;?>"><?php echo($abbreviation);?></a>
<?php } else { echo($abbreviation); }
	}
}

/**
* Function to print out admin logo.
* Uses $_SESSION['slug'].
* @return void
*/
function print_admin_logo() {

	$config = Config::getInstance();
	$slug = '';
	if (isset($_SESSION['slug'])) {
		$slug = $_SESSION['slug'];
	} 
	?>
	<span id="logo">
		<a href="<?php echo formatAppLink($config->baseurl . 'admin/index.php'); ?>"><img src="<?php echo $config->baseurl; ?>img/admin_logo.png" /></a>
	</span>
<?php
}

/**
* Function to print out admin header.
* Uses $_SESSION['admin']['game']['name'] and $_SESSION['user']['username'].
* @return void
*/
function print_admin_header() {
?>
	<div class="header_background">
		<div class="foo" style="width:50%; float:left;">
		<?php print_admin_logo(); ?>
		</div>
		<div class="foo" style="float:right; text-align:right; vertical-align: middle;">
			<table cellpadding="1" cellspacing="0">
			<?php if (isset($_SESSION['admin']['game']['name'])) : ?>
				<tr valign="top">
					<th><?php echo(localize('GAME') . ':  '); ?></th>
					<td><?php print_admin_game_name(); ?></td>
				</tr>
			<?php endif; ?>
			<?php if (isset($_SESSION['user']['username'])) : ?>
				<tr valign="top">
					<th><?php echo (localize("LOGIN_USER") . ':  '); ?></th>
					<td><?php print_admin_login(); ?></td>
				</tr>
			<?php endif; ?>
			</table>
		</div>
		<div style="clear:both;"></div>
	</div>
<?php
}

/**
* Function to print out admin footer.
* Uses $_SESSION['lang'].
* @return void
*/
function print_admin_footer() {

	global $language;
	$current_lang = $language;
	if (isset($_SESSION['lang'])) {
		$current_lang = $_SESSION['lang'];
	}

	?>	
	<div class="footer" style="font-size:10px; text-align:center; padding-top:10px;">
	<?php  print_language_bar_admin($current_lang); ?><br /><br />
	This work is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by/3.0/" target="_blank">Creative Commons Attribution 3.0 Unported License</a>.
	</div>
<?php
}

/**
* Function to read cards from csv file.
* Ignores first line of a file.
* @param string $file a path to csv file.
* @return An array of cards ready to be imported.
*/
function get_cards_from_csv($file) {
	
	$cards = array();
	$row = 1;
	
	if (($handle = fopen($file, "r")) !== FALSE) {

		while (($data = fgetcsv($handle, 0, ';')) !== FALSE) {
        	
			if ($row > 2) { // ignore headers & comments
					
				$card_data = array();
            
            foreach ($data as $field) {
            	
            	$card_data[] = Encoding::toUTF8($field);
            }
            $card = process_card($card_data);
            if ($card !== false) {
            	$cards[] = $card;
            }
			}
        	$row++;
    	}
   	fclose($handle);
	}
	return $cards;		
}

/**
* Function to process a card read from csv file with #get_cards_from_csv.
* There are 10 required fields. Rest are optional and are depending for choices and results.
* @param array $unprocessed_card contains raw card data.
* @return An array of processed card data ready to be imported.
*/
function process_card(&$unprocessed_card) {
	
	if (empty($unprocessed_card)) {
		return false;
	}
	$field_count = count($unprocessed_card);
	// There are 10 required fields. Rest are optional and are depending for choices and results
	if ($field_count < 10) {
		return false;
	}
	
	$card = array();
	$card['comment'] = $unprocessed_card[0];
	$card['card_external_id'] = 0;
	// Ignore first field
	$unprocessed_card[1] = trim($unprocessed_card[1]);
	// Remove commas, dots and empty chars
	$search  = array('.', ',', ';', ' ', '"');
	$unprocessed_card[1] = str_replace($search, '', $unprocessed_card[1]);
	if (doubleval($unprocessed_card[1]) > 0) {
		$card['card_external_id'] = doubleval($unprocessed_card[1]);
	}
	$card['enabled'] = 1;
	if ($unprocessed_card[2] == 'yes') {
		$card['repetitive'] = 1;
	}
	else {
		$card['repetitive'] = 0;
	}
	$card['card_name'] = $unprocessed_card[3];
	$card['description'] = $unprocessed_card[4];
	
	$data_array = explode('#', $unprocessed_card[5]);
	$card['tags'] = array();
	$card_tags = array();
	foreach ($data_array as $tag) {
		$trimmed = trim($tag);
		if (!empty($trimmed)) {
			// find if there is a space
			$pos = strrpos($trimmed, " ");
			if ($pos !== false) {
				$trimmed = substr($trimmed, 0, $pos);
			}
			//TODO: validate or filter other unsuitable chars too
			$card_tags[] = $trimmed;
		}
	}
	$card['tags'] = $card_tags;
	$card['stats'] = $unprocessed_card[6];
	$card['expert_advice'] = $unprocessed_card[7];
	$card['attachment'] = $unprocessed_card[8];
	$card['nbr_of_choices'] = intval($unprocessed_card[9]);
	$card['choices'] = array();
	$card['results'] = array();
	
	// To keep track where we are
	$index = 10;
	
	// Parse choices
	for ($i = 0; $i < $card['nbr_of_choices']; $i++) {
		
		$choice = array();
		$choice['ordinal'] = ($i + 1);
		$choice['text'] = '';
		$choice['nbr_of_results'] = 0;
		
		if (isset($unprocessed_card[$index]) && isset($unprocessed_card[($index+1)])) {
			$choice['text'] = $unprocessed_card[$index];
			$choice['nbr_of_results'] = intval($unprocessed_card[($index+1)]);
			$card['choices'][] = $choice;
			$index = $index + 2;
		}
		
		$results = array();
		// Parse results
		for ($j = 0; $j < $choice['nbr_of_results']; $j++) {
			
			$result = array();
			$result['weight'] = 0;
			$result['stat_changes'] = '';
			$result['next_criteria'] = '';
			$result['ordinal'] = ($j + 1);
			$result['choice_ordinal'] = $choice['ordinal'];
			$result['text'] = '';
			
			if (isset($unprocessed_card[$index]) && isset($unprocessed_card[($index+1)]) && isset($unprocessed_card[($index+2)]) && isset($unprocessed_card[($index+3)])) {
				
				if (intval($unprocessed_card[$index]) > 0 && intval($unprocessed_card[$index]) <= 100) {
					$result['weight'] = intval($unprocessed_card[$index]);
				}
				$result['text'] = $unprocessed_card[$index+1];
				$result['stat_changes'] = $unprocessed_card[($index+2)];
				$result['next_criteria'] = $unprocessed_card[($index+3)];
				
				$results[] = $result;
				$index = $index + 4;
			}
		}
		// Balance results weights
		$weight_left = 100;
		$weightless_results_indexes = array();
		
		for ($k = 0; $k < count($results); $k++) {
			
			$weight_left = $weight_left - $results[$k]['weight'];
			
			if ($results[$k]['weight'] == 0) {
				$weightless_results_indexes[] = $k;
			}
		}
		// If weights don't add up to 100 % and there's no weightless results balance all
		if (($weight_left > 0 && count($weightless_results_indexes) == 0) || $weight_left < 0 || ($weight_left == 0 && count($weightless_results_indexes) > 0)) {	
			$weightless_results_indexes = array();
			for ($k = 0; $k < count($results); $k++) {
				$weightless_results_indexes[] = $k;
			}
			$weight_left = 100;
		}
		
		if (count($weightless_results_indexes) > 0) {
			
			$weight = ceil($weight_left/count($weightless_results_indexes));
			for ($k = 0; $k < count($results); $k++) {
			
				if (in_array($k, $weightless_results_indexes)) {
				
					if ($weight > $weight_left) {
						$weight = $weight_left;
					}
					$weight_left = $weight_left - $weight;
					$results[$k]['weight'] = $weight;
				}
			}
		}
		$card['results'][] = $results;
		
		// Skip unused results
		while(empty($unprocessed_card[$index]) && $index < $field_count) {
			$index++;
		}
	}
	
	return $card;
}