<?php
/**
*	@file app_form_handling.php
*	@brief A file to handle forms in application.
*/

/** An array to hold possible errors in submitted form. */
$form_errors = array();

/**
* Function to process application forms.
* Processes application forms according to $_POST variable and stores possible errors to #$form_errors.
* @return void
*/
function process_app_forms() {
	
	global $form_errors;
	// Boolean to check if form contains errors
	$error = false;
	/** Configuration instance of Config */
	$config = Config::getInstance();
	/** array $form_data An array to hold processed form data. */
	$form_data = array();
	/** FormHandler $form_handler For validating and sanitizing the data. */
	$form_handler = new FormHandler();
	
	// Change password form is submitted
	if (isset($_POST['change_password'])) {
		
		if (isset($_POST['notifications'])) {
			unset($_POST['notifications']);
		}
		$form_data['user'] = array();
		$form_errors['user']['settings'] = array();
		
		if (isset($_POST['user']['settings']['new_password'])) {
			
			$data = $form_handler->SanitizeString($_POST['user']['settings']['new_password'], PASSWORD_MAX_LENGTH, false);
			
			if (!$data) {
				$error = true;
				$form_errors['user']['settings']['new_password'] = $form_handler->_latest_error;
			}
			else {
				$form_data['settings']['new_password'] = $data;
			}
		}
		if (isset($_POST['user']['settings']['new_password2'])) {
			
			$data = $form_handler->SanitizeString($_POST['user']['settings']['new_password2'], PASSWORD_MAX_LENGTH, false);
			
			if (!$data) {
				$error = true;
				$form_errors['user']['settings']['new_password2'] = $form_handler->_latest_error;
			}
			else {
				$form_data['settings']['new_password2'] = $data;
			}
		}
		if (!$error && isset($form_data['settings']['new_password']) && isset($form_data['settings']['new_password2'])) {
			
			if ($form_data['settings']['new_password'] !== $form_data['settings']['new_password2']) {
				$error = true;
				$form_errors['user']['settings']['new_password2'] = localize('ERROR_FORM_HANDLER_PASSWORD_MATCH');
			}
		}
		if (isset($_POST['user']['settings']['current_password'])) {
			
			$data = $form_handler->SanitizeString($_POST['user']['settings']['current_password'], PASSWORD_MAX_LENGTH, false);
			
			if (!$data) {
				$error = true;
				$form_errors['user']['settings']['current_password'] = $form_handler->_latest_error;
			}
			else {
				$form_data['settings']['current_password'] = $data;
				
				if (isset($_SESSION['user']['username'])) {
					$db = DB::getInstance();
					// Try to change the password
					if (!$db->changePassword($_SESSION['user']['username'], $form_data['settings']['current_password'], $form_data['settings']['new_password'])) {
						$error = true;
						$form_errors['user']['settings']['current_password'] = localize('ERROR_ADMIN_EDITOR_PASSWORD');
					}
				}
				else {
					$error = true;
				}
			}
		}
		// If form is valid
		if (!$error) {
			unset($_POST['user']['settings']['new_password']);
			unset($_POST['user']['settings']['new_password2']);
			unset($_POST['user']['settings']['current_password']);
			unset($_POST['change_password']);
			$_POST['notifications'] = array();
			$_POST['notifications']['password_changed'] = true;
		}
		else {
			$_POST['notifications'] = array();
			$_POST['notifications']['password_changed'] = false;
		}
	}
	// Open game form is submitted
	if (isset($_POST['user_open_game'])){
		
		$form_data['open_game'] = array();
		$form_errors['user']['settings']['open_game'] = array();
		
		if (isset($_POST['user']['settings']['open_game']['game_name']) && !empty($_POST['user']['settings']['open_game']['game_name'])) {
			
			$data = $form_handler->ValidateInt($_POST['user']['settings']['open_game']['game_name']);

			if (!$data) {
				$error = true;
				$form_errors['user']['settings']['open_game']['game_name'] = $form_handler->_latest_error;
			}
			else {
				$form_data['open_game']['profile_id'] = $data;
			}
		}
		else {
			$form_errors['user']['settings']['open_game']['game_name'] = localize('APP_SIMULATION_ERROR_NOTHING_SELECTED');
		}
		// If form is valid
		if (!$error) {
			
			if (isset($form_data['open_game']['profile_id']) && isset($_SESSION['user']['user_id']) && isset($_SESSION['isLogged']) && $_SESSION['isLogged']) {
				
				$profile_id = $form_data['open_game']['profile_id'];
				$db = DB::getInstance();
				// If return value isn't game array check error code and set correct error message
				if (!$game = $db->continueGame($profile_id)) {
					$form_errors['user']['settings']['open_game']['game_name'] = localize('ERROR_GAME_NOT_FOUND');
				}
				else {
					unset($_POST['user']['settings']['open_game']);
					$_SESSION['game'] = $game;
					unset($_POST['user_open_game']);
					unset($form_errors);
					header('Location: ' . formatAppLink($config->baseurl . 'app/simulation.php?game_slug=' . $game['slug']));
					die();
				}
			}
		}
	}
	// Delete user profile form is submitted
	if (isset($_POST['delete_profile_modal_yes_button'])){
		
		if (isset($_SESSION['user']['user_id']) && isset($_SESSION['isLogged']) && $_SESSION['isLogged']) {
				
			$user_id = $_SESSION['user']['user_id'];
			
			$db = DB::getInstance();
			$users_games = $db->getUsersGames($user_id);
			foreach ($users_games as $game) {
				$db->deleteProfile($game['profile_id']);
			}
			$db->deleteUser($user_id);
			unset($_POST['delete_profile_modal_yes_button']);
			$_POST['profile_deleted'] = true;
			header('Location: ' . formatAppLink($config->baseurl . 'general/logout.php'));
			die();
		}
	}
}