<?php
/**
*	@file app_index_form_handling.php
*	@brief A file to handle forms in application index.php.
*/

/** An array to hold possible errors in submitted form. */
$form_errors = array();

/**
* Function to process application index forms.
* Processes application index forms according to $_POST variable and stores possible errors to #$form_errors.
* @return void
*/
function process_app_index_forms() {
	
	// Clear previous notifications
	unset($_POST['notifications']);
	/** Configuration instance of Config */
	$config = Config::getInstance();
	global $form_errors;
	// Boolean to check if form contains errors
	$error = false;
	/** array $form_data An array to hold processed form data. */
	$form_data = array();
	/** FormHandler $form_handler For validating and sanitizing the data. */
	$form_handler = new FormHandler();
	
	// Start new game form is submitted
	if (isset($_POST['app_start_new_game'])) {
		
		$form_data['new_game'] = array();
		$form_errors['app']['new'] = array();
		
		if (isset($_POST['app']['new']['game_name'])) {
			
			$data = $form_handler->ValidateInt($_POST['app']['new']['game_name']);
			if (!$data) {
				$error = true;
				$form_errors['app']['new']['game_name'] = $form_handler->_latest_error;
			}
			else {
				$form_data['new_game']['game_id'] = $data;
			}
		}
		else {
			$form_errors['app']['new']['game_name'] = localize('ERROR_FORM_HANDLER_EMPTY');
		}
		
		if (isset($_POST['app']['new']['username'])) {
			
			$data = $form_handler->SanitizeString($_POST['app']['new']['username'], USERNAME_MAX_LENGTH, false);
			
			if (!$data) {
				$error = true;
				$form_errors['app']['new']['username'] = $form_handler->_latest_error;
			}
			else {
				$form_data['new_game']['username'] = $data;
			}
		}
		// If form is valid
		if (!$error) {
			
			if (isset($form_data['new_game']['game_id']) && isset($form_data['new_game']['username'])) {
				
				$game_id = $form_data['new_game']['game_id'];
				$username = $form_data['new_game']['username'];
				
				$db = DB::getInstance();
				
				if (!$game = $db->startNewGame($game_id, $username)) {
					
					$form_errors['app']['new']['game_name'] = localize('ERROR_GAME_NOT_FOUND');
				}
				else {
					if (isset($_SESSION['user']['user_id'])) {
						$db->updatePlayerProfileUser($game['profile_id'], $_SESSION['user']['user_id']);
					}
					unset($_POST['app']['new']);
					$_SESSION['game'] = $game;
					unset($_POST['app_start_new_game']);
					unset($form_errors);
					
					$_SESSION['user']['username'] = $form_data['new_game']['username'];
					header('Location: ' . formatAppLink($config->baseurl . 'app/simulation.php?game_slug=' . $game['slug']));
					die();
				}
			}
		}
	}
	
	// Open game form is submitted
	if (isset($_POST['app_open_game'])){
		
		$form_data['open_game'] = array();
		$form_errors['app']['open'] = array();
		
		if (isset($_POST['app']['open']['game_name']) && !empty($_POST['app']['open']['game_name'])) {
			
			$data = $form_handler->ValidateInt($_POST['app']['open']['game_name']);
			
			if (!$data) {
				$error = true;
				$form_errors['app']['open']['game_name'] = $form_handler->_latest_error;
			}
			else {
				$form_data['open_game']['profile_id'] = $data;
			}
		}
		else {
			$form_errors['app']['open']['game_name'] = localize('APP_SIMULATION_ERROR_NOTHING_SELECTED');
		}
		// If form is valid
		if (!$error) {
			
			if (isset($form_data['open_game']['profile_id']) && isset($_SESSION['user']['user_id']) && isset($_SESSION['isLogged']) && $_SESSION['isLogged']) {
				
				$profile_id = $form_data['open_game']['profile_id'];
				$db = DB::getInstance();
				// If return value isn't game array check error code and set correct error message
				if (!$game = $db->continueGame($profile_id)) {
					$form_errors['app']['open']['game_name'] = localize('ERROR_GAME_NOT_FOUND');
				}
				else {
					unset($_POST['app']['open']);
					$_SESSION['game'] = $game;
					unset($_POST['app_open_game']);
					unset($form_errors);
					header('Location: ' . formatAppLink($config->baseurl . 'app/simulation.php?game_slug=' . $game['slug']));
					die();
				}
			}
		}
	}
	
	// Continue game form is submitted
	if (isset($_POST['app_continue'])) {
		
		if (isset($_SESSION['game']['name']) && isset($_SESSION['user']['username'])) {
			
			unset($_POST['app_continue']);
			// Just redirect user back to simulation
			header('Location: ' . formatAppLink($config->baseurl . 'app/simulation.php?game_slug=' . $_SESSION['game']['slug']));
			die();
		}
	}
	
	// Registration form is submitted
	if (isset($_POST['app_register'])) {
		
		$form_data['register'] = array();
		$form_errors['app']['register'] = array();

		if (isset($_POST['app']['register']['username'])) {
			
			$data = $form_handler->SanitizeString($_POST['app']['register']['username'], USERNAME_MAX_LENGTH, false);
			
			if (!$data) {
				$error = true;
				$form_errors['app']['register']['username'] = $form_handler->_latest_error;
			}
			else {
				$form_data['register']['username'] = $data;
			}
		}
		if (isset($_POST['app']['register']['password'])) {
			
			$data = $form_handler->SanitizeString($_POST['app']['register']['password'], PASSWORD_MAX_LENGTH, false);
			
			if (!$data) {
				$error = true;
				$form_errors['app']['register']['password'] = $form_handler->_latest_error;
			}
			else {
				$form_data['register']['password'] = $data;
			}
		}
		if (isset($_POST['app']['register']['password2'])) {
			
			$data = $form_handler->SanitizeString($_POST['app']['register']['password2'], PASSWORD_MAX_LENGTH, false);
			
			if (!$data) {
				$error = true;
				$form_errors['app']['register']['password2'] = $form_handler->_latest_error;
			}
			else {
				$form_data['register']['password2'] = $data;
			}
		}
		if (!$error && isset($form_data['register']['password']) && isset($form_data['register']['password2'])) {
			
			if ($form_data['register']['password'] !== $form_data['register']['password2']) {
				$error = true;
				$form_errors['app']['register']['password2'] = localize('ERROR_FORM_HANDLER_PASSWORD_MATCH');
			}
		}
		// If form is valid
		if (!$error) {
			if (isset($form_data['register']['username']) && isset($form_data['register']['password'])) {
				
				$user = $form_data['register']['username'];
				$pass = $form_data['register']['password'];
				$db = DB::getInstance();
				$user_id = $db->createUser($user, $pass);

				if ($user_id > 0) {
					
					// Link current game to this account
					if (isset($_SESSION['game']['profile'])) {
						
						$profile_id = $_SESSION['game']['profile'];
						$db->updatePlayerProfileUser($profile_id, $user_id);
					}
					session_destroy();
					do_basic_operations();
					unset($_POST['app']['register']);
					unset($_POST['app_register']);
					unset($form_errors);
					if (isset($_GET['showpanel'])) {
						unset($_GET['showpanel']);
					}
					$_POST['notifications'] = array();
					$_POST['notifications']['new_user_created'] = true;
				}
				else {
					
					if ($user_id == -1) {
						$form_errors['app']['register']['username'] = localize('ERROR_USER_EXISTS');
					}
				}
			}
		}
	}
	
	// Login form is submitted
	if (isset($_POST['app_login'])){
		
		$form_data['login'] = array();
		$form_errors['app']['login'] = array();
		
		if (isset($_POST['app']['login']['username'])) {
			
			$data = $form_handler->SanitizeString($_POST['app']['login']['username'], USERNAME_MAX_LENGTH, false);
			
			if (!$data) {
				$error = true;
				$form_errors['app']['login']['username'] = $form_handler->_latest_error;
			}
			else {
				$form_data['login']['username'] = $data;
			}
		}
		if (isset($_POST['app']['login']['password'])) {
			
			$data = $form_handler->SanitizeString($_POST['app']['login']['password'], PASSWORD_MAX_LENGTH, false);
			
			if (!$data) {
				$error = true;
				$form_errors['app']['login']['password'] = $form_handler->_latest_error;
			}
			else {
				$form_data['login']['password'] = $data;
			}
		}
		// If form is valid
		if (!$error) {
			
			if (isset($form_data['login']['username']) && isset($form_data['login']['password'])) {
				
				$username = $form_data['login']['username'];
				$pass = $form_data['login']['password'];
				
				$db = DB::getInstance();
				// If return value isn't game array check error code and set correct error message
				if (!is_array($user = $db->login($username, $pass))) {
					// Errors:	-1: given user isn't found, -2: wrong password
					if ($user < 0) {
						$form_errors['app']['login']['username'] = localize('ERROR_LOGIN');
						$form_errors['app']['login']['password'] = localize('ERROR_LOGIN');
					}
				}
				else {
					//TODO: Ask if user wants to add current game profile to his/hers account
					unset($_POST['app']['login']);
					unset($_POST['app_login']);
					unset($form_errors);
				}
			}
		}
	}
}