<?php
/**
*	@file end.php
*	@brief Simulation ending page.
*	Gets shown if simulation ended.
*/
require_once(dirname(__FILE__) . '/app_functions.php');
do_basic_operations();
/** Database instance of either #MySQLDB or #XMLDB */
$db = DB::getInstance();
/** Configuration instance of Config */
$config = Config::getInstance();
/** Get current simulation value from get parameter if not exist show 404 page */
$current_simulation = 0;

$slug = '';
if (isset($_GET['game_slug'])) {
	
	$slug = friendly_url($_GET['game_slug']);

	if (isset($_SESSION['game']['slug']) && $_SESSION['game']['slug'] == $slug) {
		$current_simulation = $_SESSION['game']['game_id'];
	}
	else {
		// Get corresponding game_id based on given slug
		$game_id = $db->getGameIdBySlug($slug);
		
		if ($game_id > 0) {
			$current_simulation = $game_id;
		}
	}
}
if ($current_simulation < 1) {
	header("HTTP/1.0 404 Not Found");
	exit("Not Found");
}

// if user edited settings process forms
if (isset($_POST['change_password']) || isset($_POST['user_open_game']) || isset($_POST['delete_profile_modal_yes_button'])) {
	process_app_forms();
}
	
if (isset($_SESSION['user']['username']) && isset($_SESSION['game']['game_id']) && isset($_SESSION['game']['name']) && isset($_SESSION['game']['profile']) ){//&& isset($_SESSION['game']['ending'])) {
  	$username = $_SESSION['user']['username'];
  	$game_id = $_SESSION['game']['game_id'];
  	$game_name = $_SESSION['game']['name'];
  	$profile_id = $_SESSION['game']['profile'];
}
else {
	header('Location: ' . formatAppLink($config->baseurl . 'app/index.php?game_slug=' . $slug));
	die();
}

/** Global default language. */
global $language;
/** Assign global default $language to $current_lang. */
$current_lang = $language;

if (isset($_SESSION['lang'])) {
	$current_lang = $_SESSION['lang'];
}

/** GameEngine object containing simulation specific information based on $game_id and $profile_id. */
$game = new GameEngine($game_id, $profile_id, $current_lang);
// If game hasn't yet ended redirect user back to simulation
if (!$game->game_ended) {
	header('Location: ' . formatAppLink($config->baseurl . 'app/simulation.php?game_slug=' . $slug));
	die();
}
// Get game texts from db and define which translation to use
/** 
 * Contains information of texts of the current game retrieved by MySQLDB::getAllGames
 * or XMLDB::getGameTexts.
 */
$game_texts = $db->getGameTexts($game_id);
/** Game texts in default language. */
$default_lang_texts = array();
/** Game texts in currently active language. */
$current_lang_texts = array();

// Loop through texts array and find correct translations
foreach ($game_texts as $trans) {
	if ($trans['language_code'] == $current_lang) {
		$current_lang_texts = $trans;
	}
	if ($trans['is_default'] == 1) {
		$default_lang_texts = $trans;
	}
	// If both are found then break
	if (!empty($current_lang_texts) && !empty($default_lang_texts)) {
		break;
	}
}

/** If translation for current language is found contains texts of that. Otherwise texts are in default language. */
$texts = array();

// If translation for current language is found use that. Otherwise use default one
if (!empty($current_lang_texts)) {
	$texts = $current_lang_texts;
}
else {
	$texts = $default_lang_texts;
}

print_app_html_start('APP_INDEX_TITLE');
print_app_header($game->player_stats);
/** Contains simulation ending page errors */
$app_form_errors = array();
/** An array to hold errors in form if any. Defined in app_form_handling.php */
global $form_errors;

if (!empty($form_errors)) {
	$app_form_errors = $form_errors;
}

if ($current_simulation > 0) :
	$this_game = $db->getGame($current_simulation);
?>
<style>
<!--
<?php // Custom background color
	if (isset($this_game['background_color']) && !empty($this_game['background_color'])) :
?>
html, input[type="text"], input[type="password"] {
	background-color: <?php echo('#' . $this_game['background_color']); ?>;
	background-image: none;
}
.simulation_select, .hidden_header_show_hide, .hidden_header {
	color: <?php echo('#' . $this_game['background_color']); ?>;
}
.selected_language {
	color: <?php echo('#' . $this_game['background_color']); ?> !important;
}
/* Pop ups: */
.jqmWindow, .jqmDialog, .jqmUserSettings, .jqmDialog2 {
	background-color: <?php echo('#' . $this_game['background_color']); ?>;
}
<?php 
	endif;
	// Custom background tile
	if (isset($this_game['background_tile']) && !empty($this_game['background_tile'])) :
		global $image_folder;
		$current_image_folder = $image_folder;
		if (isset($this_game['image_folder']) && !empty($this_game['image_folder'])) {
			$current_image_folder = $this_game['image_folder'];
		}
		$config = Config::getInstance();
		$background_tile_url = $config->baseurl . $current_image_folder . $this_game['background_tile'];
?>
html {
	background-image: url(<?php echo($background_tile_url); ?>);
}
<?php 
	endif;
	// Custom text color
	if (isset($this_game['text_color']) && !empty($this_game['text_color'])) :
?>
html, h1, h2, h3, h4, h5, p, label, hr {
	color: <?php echo('#' . $this_game['text_color']); ?>;
}
.hidden_header_background_repeat {
	/* box-shadow: 0 1px 5px <?php echo('#' . $this_game['text_color']); ?>;*/
	 background-color: <?php echo('#' . $this_game['text_color']); ?>;
}
.hidden_header {
	 background-color: <?php echo('#' . $this_game['text_color']); ?>;
}
input[type="text"], input[type="password"] {
    border: 1px solid <?php echo('#' . $this_game['text_color']); ?>;
    color: <?php echo('#' . $this_game['text_color']); ?>;
}
<?php 
	endif;
	// Custom link color
	if (isset($this_game['link_color']) && !empty($this_game['link_color'])) :
?>
a, .hidden_header_show_hide:hover, #hidden_header_columns a, #hidden_header_columns dd {
	color: <?php echo('#' . $this_game['link_color']); ?>;
}
.simulation_select {
	background-color: <?php echo('#' . $this_game['link_color']); ?>;
}
<?php 
	endif;
	// Custom link hover color
	if (isset($this_game['link_hover_color']) && !empty($this_game['link_hover_color'])) :
?>
a:hover, #hidden_header_columns a:hover {
	color: <?php echo('#' . $this_game['link_hover_color']); ?>;
}
<?php 
	endif;
	// Custom button color
	if (isset($this_game['button_color']) && !empty($this_game['button_color'])) :
?>
button, input[type="submit"], #delete_profile_button {
	color: <?php echo('#' . $this_game['button_color']); ?>;
}
<?php 
	endif;
	// Custom button hover color
	if (isset($this_game['button_hover_color']) && !empty($this_game['button_hover_color'])) :
?>
button:hover, input[type="submit"]:hover, #delete_profile_button:hover {
	color: <?php echo('#' . $this_game['button_hover_color']); ?>;
}
<?php 
	endif;
?>
-->
</style>
<?php
	// Custom logo
	if (isset($this_game['logo']) && !empty($this_game['logo'])) :
		global $image_folder;
		$current_image_folder = $image_folder;
		if (isset($this_game['image_folder']) && !empty($this_game['image_folder'])) {
			$current_image_folder = $this_game['image_folder'];
		}
		$config = Config::getInstance();
		$logo_url = $config->baseurl . $current_image_folder . $this_game['logo'];
?>
<style>	
<!--
.hidden_header_logo, .hidden_header_logo:hover {
	background-image: url("<?php echo($logo_url); ?>");
	background-size: contain;
}
-->
</style>
<?php	
	endif;
endif;
?>
<?php 
/** Contains information about current card in play from GameEngine::getCurrentCard. */
$current_card = $game->getCurrentCard();
/** Contains number of played cards retrieved with GameEngine::countPlayedCards. */
$played_cards_count = $game->countPlayedCards();
/** Global default image folder location. */
global $image_folder;

if (empty($_SESSION['game']['image_folder'])) {
	$_SESSION['game']['image_folder'] = str_replace('\\', '/', $image_folder);
}

/** GameEngine object is stored to session variable. */
$_SESSION['game_object'] = $game; 

$show_user_settings = false;
if (!empty($app_form_errors['user']['settings'])) {
	$show_user_settings = true;
}
if (isset($_POST['notifications']['password_changed'])) {
	$show_user_settings = true;
}
?>
	<div class="clear"></div>
	<div id="panel_wrapper" class="panel_wrapper">
	
		<div id="panel_mask_end" class="panel_mask">
			<div id="simulation_ending_panel" class="panel_item panel_item_end">
				<div class="panel_content" >
				<?php if (!$game->panic) : ?>
					<input type="hidden" id="current_card_id" value="<?php if($played_cards_count > 0 && isset($current_card['card_id'])) : echo($current_card['card_id']); else: echo('0'); endif; ?>" />
					<?php if(isset($current_card['attachment']) && !empty($current_card['attachment'])): ?>
					<div id="simulation_card_image">
						<img src="<?php echo($config->baseurl . $_SESSION['game']['image_folder'] . $current_card['attachment']); ?>" alt="<?php echo localize("IMAGE_ALT_CARD"); ?>" />
					</div>
					<?php endif; ?>
					<h1 id="simulation_card_name"><?php if(isset($current_card)): if (!empty($current_card['card_name'])): echo($current_card['card_name']); elseif (!empty($current_card['default_name'])): echo($current_card['default_name']); endif; else: echo('N/A'); endif; ?></h1>
					<p id="simulation_card_description">
					<?php if (isset($current_card['description']) && !empty($current_card['description'])) :
								echo($current_card['description']);
							elseif (isset($current_card['default_description']) && !empty($current_card['default_description'])) :
								echo($current_card['default_description']); 
							else: echo('N/A');
							endif;
					?>
					</p>
				<?php else : //TODO: maybe picture here? ?>
					<?php // increase number of card by one so that every card is shown
							// because there's no actual ending card present
							$played_cards_count = $played_cards_count + 1;		
					?>
					<h1 id="simulation_card_name"><?php echo localize('APP_SIMULATION_GAME_ENDED_NO_SUITABLE_CARDS_LEFT_HEADER'); ?></h1>
					<p id="simulation_card_description"><?php echo localize('APP_SIMULATION_GAME_ENDED_NO_SUITABLE_CARDS_LEFT_DESCRIPTION'); ?></p>
				<?php endif; ?>
				<?php // count of played_cards represents the cards get not the choices made ?>
					<h3><a href="#" <?php if ($played_cards_count < 2 || !$game->allowCancellation()) : ?>style="display:none;"<?php endif; ?> class="main_link" id="back_to_simulation_button" ><?php echo localize('APP_SIMULATION_BACK_TO_SIMULATION'); ?></a></h3>
					<h3><a class="main_link" id="simulation_menu" href="<?php echo formatAppLink($config->baseurl . 'app/index.php?game_slug=' . $slug); ?>"><?php echo localize('APP_SIMULATION_MAIN_MENU'); ?></a></h3>
						
					<div id="debug">
						<input type="hidden" id="simulation_debug_player_profile" value="<?php echo $profile_id; ?>" />
						<br />
					</div>
<?php if (isset($_SESSION['game']['show_cards_ending']) && $_SESSION['game']['show_cards_ending']) : ?>
					<h2><?php echo(localize("APP_SIMULATION_RECEIVED_CARDS")); ?></h2>
					<br />
					
			<?php $played_cards = $db->getPlayedCards($profile_id);
					
					for ($i = 0; $i < ($played_cards_count-1);  $i++) :
						
						$card = $db->getCard($played_cards[$i]['card_id'], $current_lang); ?>
						<div class="simulation_end_played_card">
							<div class="simulation_end_played_card_image">
				<?php if (isset($card['attachment']) && !empty($card['attachment'])): ?>
								<img src="<?php echo($config->baseurl . $_SESSION['game']['image_folder'] . $card['attachment']); ?>" alt="<?php echo localize("IMAGE_ALT_CARD"); ?>" />
				<?php endif; ?>
							</div>
							<div class="simulation_end_played_card_content">
								<h3><?php if (!empty($card['card_name'])): echo($card['card_name']); elseif (!empty($card['default_name'])): echo($card['default_name']); else: echo('N/A'); endif; ?></h3>
								<p class="simulation_end_played_card_description"><?php if (isset($card['description'])  && !empty($card['description'])) : echo($card['description']); elseif (isset($card['default_description']) && !empty($card['default_description'])) : echo($card['default_description']);  else: echo('N/A'); endif; ?></p>
				<?php if ($played_cards[$i]['choice_id'] > 0 && $played_cards[$i]['result_id'] > 0) :
							
							$result = $db->getResult($played_cards[$i]['result_id'], $current_lang);
							$choice = array();
							
							foreach ($card['choices'] as $card_choice) {
								if ($card_choice['choice_id'] == $played_cards[$i]['choice_id']) {
									$choice = $card_choice;
									break;
								}
							}
							if (!empty($result) && !empty($choice)) : ?>
								<p class="simulation_end_played_card_choice"><span class="strong"><?php echo(localize("CHOICE") . ': '); ?></span><?php if (isset($choice['choice_text']) && !empty($choice['text'])) : echo($choice['choice_text']); elseif (isset($choice['default_text']) && !empty($choice['default_text'])) : echo($choice['default_text']);  else: echo('N/A'); endif; ?></p>
								<p class="simulation_end_played_card_result"><span class="strong"><?php echo(localize("APP_SIMULATION_RESULT") . ': '); ?></span><?php if (isset($result['result_text']) && !empty($result['result_text'])) : echo($result['result_text']); elseif (isset($result['default_text']) && !empty($result['default_text'])) : echo($result['default_text']);  else: echo('N/A'); endif; ?></p>
					<?php endif;
						endif; ?>
							</div>
							<hr />
						</div>
			<?php endfor;?>
<?php endif; ?>
				</div>
			</div>
			
		</div>
	</div>
	<div class="clear"></div>
	
	<div class="jqmUserSettings" id="user_settings_modal">
		<a href="#" class="jqmClose" id="user_settings_modal_close"><?php echo localize('CLOSE'); ?></a>
		<h2><?php echo localize('ADMIN_EDITOR_USER_SETTINGS')?></h2>
		<br />
<?php if ($_POST['notifications']['password_changed']) : ?>
		<p class="notification">
			<?php echo localize('ADMIN_EDITOR_NOTIFICATION_PASSWORD_CHANGED'); ?>
		</p>
<?php endif; ?>
		<form id="user_settings_form" class="app_form" method="post" action="">
			<div class="left" id="user_settings_left">
				<label for="user[settings][new_password]"><?php echo localize('ADMIN_EDITOR_CHANGE_PASSWORD')?></label><input class="" type="password" name="user[settings][new_password]" id="user[settings][new_password]" value="<?php if(isset($_POST['user']['settings']['new_password'])) echo $_POST['user']['settings']['new_password']; ?>" />
				<?php	if (isset($app_form_errors['user']['settings']['new_password'])) : ?>
				<p class="error"><?php echo $app_form_errors['user']['settings']['new_password']; ?></p>
				<?php endif; ?>
				<label for="user[settings][new_password2]"><?php echo localize('ADMIN_EDITOR_CHANGE_PASSWORD2')?></label><input class="" type="password" name="user[settings][new_password2]" id="user[settings][new_password2]" value="<?php if(isset($_POST['user']['settings']['new_password2'])) echo $_POST['user']['settings']['new_password2']; ?>" />
				<?php	if (isset($app_form_errors['user']['settings']['new_password2'])) : ?>
				<p class="error"><?php echo $app_form_errors['user']['settings']['new_password2']; ?></p>
				<?php endif; ?>
				<label for="user[settings][current_password]"><?php echo localize('ADMIN_EDITOR_CURRENT_PASSWORD')?></label><input class="" type="password" name="user[settings][current_password]" id="user[settings][current_password]" value="<?php if(isset($_POST['user']['settings']['current_password'])) echo $_POST['user']['settings']['current_password']; ?>" />
				<?php	if (isset($app_form_errors['user']['settings']['current_password'])) : ?>
				<p class="error"><?php echo $app_form_errors['user']['settings']['current_password']; ?></p>
				<?php endif; ?>
				<br />
				<input class="" type="submit" class="" id="change_password" name="change_password" value="<?php echo localize('SAVE')?>" />
			</div>
			<div class="right" id="user_settings_right">
				<button class="right" id="delete_profile_button" name="delete_profile_button"><?php echo localize('ADMIN_EDITOR_DELETE_PROFILE')?></button>
			</div>
			<div class="clear"></div>
			<br />
			<?php $user_games = array(); ?>
			<?php if (isset($_SESSION['user']['user_id'])): $user_games = $db->getUsersGames($_SESSION['user']['user_id']); endif; ?>
			<?php print_app_saved_games($user_games, $current_simulation); ?>
			<br />
		</form>
	</div>
	
	<?php print_app_delete_saved_game_modal(); ?>
	
	<div id="delete_profile_modal" class="jqmDialog jqmdWide">
		<a href="#" class="jqmClose" id="delete_profile_modal_close"><?php echo localize('CLOSE'); ?></a>
		<div class="jqmdBL"><div class="jqmdBR"><div class="jqmdBC">

		<div class="jqmdMSG">
			<br />
			<br />
			<div class="centered largeText">
				<?php echo localize('APP_SIMULATION_CONFIRM_DELETE_PROFILE')?>
			</div>
			<p><?php echo localize('APP_SIMULATION_CONFIRM_DELETE_PROFILE_DESCRIPTION')?></p>
			<br />
			<form method="post" action="#">
				<div class="centered buttons">
					<input type="submit" class="" id="delete_profile_modal_yes_button" name="delete_profile_modal_yes_button" value="<?php echo localize("YES"); ?>" />
					<input type="submit" class="jqmClose" id="delete_profile_modal_no_button" name="delete_profile_modal_no_button" value="<?php echo localize("NO"); ?>" />
				</div>
			</form>
		</div>

		</div></div></div>

	</div>
		
<script type="text/javascript">
<!--
$(document).ready(function() {
	
// Show user settings popup when needed
<?php if ($show_user_settings) : ?>
	$('#user_settings_button').click();
<?php endif; ?>
});
//-->
</script>
	
<?php 
print_html_end();
?>