<?php 
/**
*	@file app/index.php
*	@brief Simulation starting page.
*	Handles starting new simulation, opening existing game, log in and registration.
*/
require_once(dirname(__FILE__) . '/app_functions.php');
do_basic_operations();
/** Database instance of either #MySQLDB or #XMLDB */
$db = DB::getInstance();
/** Get current simulation value from get parameter if not exist show 404 page */
$current_simulation = 0;

if (isset($_GET['game_slug'])) {
			
	$slug = friendly_url($_GET['game_slug']);
			
	if (isset($_SESSION['game']['slug']) && $_SESSION['game']['slug'] == $slug) {
		$current_simulation = $_SESSION['game']['game_id'];
	}
	else {
		// Get corresponding game_id based on given slug
		$game_id = $db->getGameIdBySlug($slug);
		if ($game_id > 0) {
			$current_simulation = $game_id;
		}
	}
}
if ($current_simulation < 1) {
	header("HTTP/1.0 404 Not Found");
	exit("Not Found");
}

// if user pressed submit button process forms
if (isset($_POST['app_start_new_game']) || isset($_POST['app_open_game']) || isset($_POST['app_login']) || isset($_POST['app_register']) || isset($_POST['app_continue'])) {
	process_app_index_forms();
}

// if user edited settings process forms
if (isset($_POST['change_password']) || isset($_POST['user_open_game']) || isset($_POST['delete_profile_modal_yes_button'])) {
	process_app_forms();
}

// Get current game
$this_game;
if ($current_simulation > 0) {
	$this_game = $db->getGame($current_simulation);
}
// Get game texts from db and define which translation to use
/** 
 * Contains information of texts of the current game retrieved by MySQLDB::getAllGames
 * or XMLDB::getGameTexts.
 */
$game_texts = $db->getGameTexts($current_simulation);
/** Game texts in default language. */
$default_lang_texts = array();
/** Game texts in currently active language. */
$current_lang_texts = array();
/** Global default language. */
global $language;
/** Assign global default $language to $current_lang. */
$current_lang = $language;

if (isset($_SESSION['lang'])) {
	$current_lang = $_SESSION['lang'];
}
// Loop through texts array and find correct translations
foreach ($game_texts as $trans) {
	if ($trans['language_code'] == $current_lang) {
		$current_lang_texts = $trans;
	}
	if ($trans['is_default'] == 1) {
		$default_lang_texts = $trans;
	}
	// If both are found then break
	if (!empty($current_lang_texts) && !empty($default_lang_texts)) {
		break;
	}
}

/** If translation for current language is found contains texts of that. Otherwise texts are in default language. */
$texts = array();

// If translation for current language is found use that. Otherwise use default one
if (!empty($current_lang_texts)) {
	$texts = $current_lang_texts;
}
else {
	$texts = $default_lang_texts;
}

print_app_html_start('APP_INDEX_TITLE');
print_app_index_header($this_game);
/** Contains index page errors */
$index_form_errors = array();
/**
 * An array to hold errors in form if any. Defined in app_index_form_handling.php
 * or in app_form_handling.php
 */
global $form_errors;

if (!empty($form_errors)) {
	$index_form_errors = $form_errors;
}

if ($current_simulation > 0) :
	//$this_game = $db->getGame($current_simulation);
?>
<style>
<!--
<?php // Custom background color
	if (isset($this_game['background_color']) && !empty($this_game['background_color'])) :
?>
html, input[type="text"], input[type="password"] {
	background-color: <?php echo('#' . $this_game['background_color']); ?>;
	background-image: none;
}
.simulation_select, .hidden_header_show_hide, .hidden_header {
	color: <?php echo('#' . $this_game['background_color']); ?>;
}
.selected_language {
	color: <?php echo('#' . $this_game['background_color']); ?> !important;
}
/* Pop ups: */
.jqmWindow, .jqmDialog, .jqmUserSettings, .jqmDialog2 {
	background-color: <?php echo('#' . $this_game['background_color']); ?>;
}
<?php 
	endif;
	// Custom background tile
	if (isset($this_game['background_tile']) && !empty($this_game['background_tile'])) :
		global $image_folder;
		$current_image_folder = $image_folder;
		if (isset($this_game['image_folder']) && !empty($this_game['image_folder'])) {
			$current_image_folder = $this_game['image_folder'];
		}
		$config = Config::getInstance();
		$background_tile_url = $config->baseurl . $current_image_folder . $this_game['background_tile'];
?>
html {
	background-image: url(<?php echo($background_tile_url); ?>);
}
<?php 
	endif;
	// Custom text color
	if (isset($this_game['text_color']) && !empty($this_game['text_color'])) :
?>
html, h1, h2, h3, h4, h5, p, label, hr {
	color: <?php echo('#' . $this_game['text_color']); ?>;
}
input[type="text"], input[type="password"] {
    border: 1px solid <?php echo('#' . $this_game['text_color']); ?>;
    color: <?php echo('#' . $this_game['text_color']); ?>;
}
.hidden_header_background_repeat {
	 /*box-shadow: 0 1px 5px <?php echo('#' . $this_game['text_color']); ?>;*/
	 background-color: <?php echo('#' . $this_game['text_color']); ?>;
}
.hidden_header {
	 background-color: <?php echo('#' . $this_game['text_color']); ?>;
}
<?php 
	endif;
	// Custom link color
	if (isset($this_game['link_color']) && !empty($this_game['link_color'])) :
?>
a, .hidden_header_show_hide:hover, #hidden_header_columns a, #hidden_header_columns dd {
	color: <?php echo('#' . $this_game['link_color']); ?>;
}
.simulation_select {
	background-color: <?php echo('#' . $this_game['link_color']); ?>;
}
<?php 
	endif;
	// Custom link hover color
	if (isset($this_game['link_hover_color']) && !empty($this_game['link_hover_color'])) :
?>
a:hover, #hidden_header_columns a:hover {
	color: <?php echo('#' . $this_game['link_hover_color']); ?>;
}
<?php 
	endif;
	// Custom button color
	if (isset($this_game['button_color']) && !empty($this_game['button_color'])) :
?>
button, input[type=submit], #delete_profile_button {
	color: <?php echo('#' . $this_game['button_color']); ?>;
}
<?php 
	endif;
	// Custom button hover color
	if (isset($this_game['button_hover_color']) && !empty($this_game['button_hover_color'])) :
?>
button:hover, input[type=submit]:hover, #delete_profile_button:hover {
	color: <?php echo('#' . $this_game['button_hover_color']); ?>;
}
<?php 
	endif;
?>
-->
</style>
<?php
	// Custom logo
	if (isset($this_game['logo']) && !empty($this_game['logo'])) :
		global $image_folder;
		$current_image_folder = $image_folder;
		if (isset($this_game['image_folder']) && !empty($this_game['image_folder'])) {
			$current_image_folder = $this_game['image_folder'];
		}
		$config = Config::getInstance();
		$logo_url = $config->baseurl . $current_image_folder . $this_game['logo'];
?>
<style>	
<!--
.hidden_header_logo, .hidden_header_logo:hover {
	background-image: url("<?php echo($logo_url); ?>");
	background-size: contain;
}
-->
</style>
<?php
	endif;
endif;

$show_user_settings = false;
if (!empty($index_form_errors['user']['settings'])) {
	$show_user_settings = true;
}
if (isset($_POST['notifications']['password_changed'])) {
	$show_user_settings = true;
}
$user_games = array();
if (isset($_SESSION['user']['user_id'])) {
	$user_games = $db->getUsersGames($_SESSION['user']['user_id']);
}

/** 
 * Contains information of all games retrieved by MySQLDB::getAllGames
 * or XMLDB::getAllGames.
 */
$games = $db->getAllGames();

?>

	<div class="clear"></div>
	<div id="panel_wrapper" class="panel_wrapper">
		<div id="panel_mask_app_index" class="panel_mask">
		
			<div id="app_index_start" class="panel_item panel_item_app_index">
				<div class="panel_content" >
					<h1><?php echo $texts['welcome']; //localize('WELCOME_TEXT'); ?></h1>
					
					<div><?php echo $texts['front_up']; ?></div>
					
					<?php if (isset($_SESSION['game']['game_id'])) : ?>
					<h2><a class="panel_link" id="app_index_continue" href="#app_index_continue_panel"><?php echo localize('APP_INDEX_CONTINUE_GAME'); ?></a></h2>
					<?php endif; ?>
					<h2><a class="panel_link" id="app_index_start_new" href="#app_index_start_new_panel"><?php echo localize('APP_INDEX_NEW_GAME'); ?></a></h2>
					<?php if (isset($_SESSION['user']['username']) && isset($_SESSION['isLogged'])) : ?>
					<?php 	if (!empty($user_games)) : ?>
					<h2><a class="panel_link" id="app_index_open" href="#app_index_open_panel"><?php echo localize('APP_INDEX_OPEN_GAME'); ?></a></h2>
					<?php 	endif; ?>
					<?php else: ?>
					<?php 	if (isset($this_game['use_login']) && $this_game['use_login']) : ?>
					<h2><a class="panel_link" id="app_index_login" href="#app_index_login_panel"><?php echo localize('LOGIN'); ?></a></h2>
					<h2><a class="panel_link" id="app_index_register" href="#app_index_register_panel"><?php echo localize('REGISTER'); ?></a></h2>
					<?php 	endif; ?>
					<?php endif; ?>
					
					<?php if (!empty($texts['front_down'])) : ?>
					<div><?php echo $texts['front_down']; ?></div>
					<?php endif; ?>
				</div>
			</div>
			
			<div id="app_index_start_new_panel" class="panel_item panel_item_app_index">
				<div class="panel_content">
					<h1><?php echo localize('APP_INDEX_NEW_GAME')?></h1>
					
					<div><?php echo $texts['new_up']; ?></div>
					
					<form id="start_new_game_form" class="app_form app_index_form" method="post" action="">
						<?php if (isset($_SESSION['user']['username']) && isset($_SESSION['isLogged'])) : ?>
						<input class="" type="hidden" name="app[new][username]" id="app[new][username]" value="<?php echo $_SESSION['user']['username']; ?>" />
						<?php elseif (isset($this_game['use_name']) && !$this_game['use_name']) : ?>
						<input class="" type="hidden" name="app[new][username]" id="app[new][username]" value="<?php echo('Player'); ?>" />
						<?php else: ?>
						<label for="app[new][username]"><?php echo localize('APP_INDEX_USER_NAME'); ?>: </label><input class="" type="text" name="app[new][username]" id="app[new][username]" value="<?php if(isset($_POST['app']['new']['username'])) echo $_POST['app']['new']['username']; ?>" />
						<?php endif; ?>
						<?php	if (isset($index_form_errors['app']['new']['username'])) : ?>
						<p class="error"><?php echo $index_form_errors['app']['new']['username']; ?></p>
						<?php endif; ?>
						
						<?php // if current game is given then no need to show selection (game_name means id)?>
						<?php if (empty($current_simulation)) : ?>
						<label for="app[new][game_name]"><?php echo localize('APP_INDEX_SELECT_GAME'); ?></label>
						<select class="" name="app[new][game_name]" id="app[new][game_name]">
							<option value="" selected="selected" disabled="disabled"><?php echo localize('SELECT'); ?></option>
						
						<?php // Disable also users old games from the selection ?>
						<?php foreach($games as $game): ?>
							<?php if(isset($_POST['app']['new']['game_name'])): ?>
							<option value="<?php echo $game['game_id']; ?>" <?php if($_POST['app']['new']['game_name'] == $game['game_id']) : echo ' selected="selected"'; endif; if (in_array($game['game_id'], $users_game_ids)): echo('disabled="disabled"'); endif; ?>><?php echo $game['name']; ?></option>
							<?php else: ?>
							<option value="<?php echo $game['game_id']; ?>" <?php //if (in_array($game['game_id'], $users_game_ids)): echo('disabled="disabled"'); endif; ?>><?php echo $game['name']; ?></option>
							<?php endif; ?>			
						<?php endforeach; ?>
						<?php unset($game);?>
						</select>
						<?php // if current game is given set that value to hidden field ?>
						<?php else : ?>
						<input type="hidden" name="app[new][game_name]" id="app[new][game_name]" value="<?php echo $current_simulation; ?>" />
						<?php endif; ?>
						<?php	if (isset($index_form_errors['app']['new']['game_name'])) : ?>
						<p class="error"><?php echo $index_form_errors['app']['new']['game_name']; ?></p>
						<?php endif; ?>
						<br />
						<input type="submit" class="" name="app_start_new_game" value="<?php echo localize('START'); ?>" />
					</form>
					
					<?php if (!empty($texts['new_down'])) : ?>
					<div><?php echo $texts['new_down']; ?></div>
					<?php endif; ?>
					<h3><a href="#app_index_start" class="panel_link"><?php echo localize('BACK')?></a></h3>
				</div>
			</div>
			
			<div id="app_index_open_panel" class="panel_item panel_item_app_index">
				<div class="panel_content">
					<h1><?php echo localize('APP_INDEX_OPEN_GAME')?></h1>
					
					<div><?php echo $texts['open_up']; ?></div>
					<?php $current_game = $db->getGame($current_simulation, $language);
							global $image_folder;
							$config = Config::getInstance();
							$current_image_folder = '';
							if (isset($current_game['image_folder']) && !empty($current_game['image_folder'])) {
								$current_image_folder = $current_game['image_folder'];
							}
							else {
								$current_image_folder = $image_folder;
							}
							$current_image_folder = str_replace(array('/', '\\'), '/', $current_image_folder);
					?>
					<form id="open_game_form" class="app_form app_index_form" method="post" action="">
						<div id="user_select_simulation_loading" class="result_loading"><img src="<?php echo($config->baseurl . 'img/loading.gif'); ?>" alt="<?php echo localize('IMAGE_ALT_LOADING'); ?>" /></div>
						<h3><?php echo localize('APP_INDEX_SELECT_GAME'); ?>:</h3>
						<input type="hidden" name="app[open][game_name]" id="app[open][game_name]" value="<?php if(isset($_POST['app']['open']['game_name'])) echo($_POST['app']['open']['game_name']); ?>" />
						<div class="app_simulation_selection" id="app_simulation_selection_open_simulation">
						<?php foreach($user_games as $game) {
									// Filter other games
									if ($game['game_id'] == $current_simulation) :
						?>
							<div id="select_simulation_<?php echo $game['profile_id']; ?>" class="<?php if($_POST['app']['open']['game_name'] == $game['profile_id']) : echo 'simulation_selected '; endif; if($game['game_ended']) : echo ' simulation_disabled '; endif; ?>simulation_select">
								<?php $latest_played_card = end($db->getPlayedCards($game['profile_id']));
										$latest_card = $db->getCard($latest_played_card['card_id'], $current_lang);
										$card_image = 'img/no-image.png';
				
										if(isset($latest_card['attachment'])) {
											if (!empty($latest_card['attachment'])) {
												$card_image = $current_image_folder . $latest_card['attachment'];
											}
										}
										$card_name = '&nbsp';
										if (isset($latest_card['card_name']) && !empty($latest_card['card_name'])) {
											$card_name = $latest_card['card_name'];
										}
										elseif (isset($latest_card['default_name'])) {
											$card_name = $latest_card['default_name'];
										}
								?>
								<span class="select_simulation_image" style="margin-left: 5px;"><img src="<?php echo($config->baseurl . $card_image); ?>" alt="<?php echo localize("IMAGE_ALT_CARD"); ?>" /></span>
								<span class="select_simulation_center">
								<span>
								<?php echo(localize('APP_SIMULATION_STARTING_DATE') . ': ' . date(localize('DATE_FORMAT'), strtotime($game['profile_created']))); ?></span>
								<?php if($game['game_ended']) : ?>
								<span class="right"><?php echo localize('APP_SIMULATION_OPEN_FINISHED')?></span>
								<?php endif;?>
								<br /><span><?php echo(localize('APP_SIMULATION_LATEST') . ': ' . $card_name) ?></span>
								</span>
								<span class="right app_select_simulation_start"></span>
							</div>	
						<?php 	endif;
								}
								unset($game);
						?>
						</div>
						<?php	if (isset($index_form_errors['app']['open']['game_name'])) : ?>
						<p class="error"><?php echo $index_form_errors['app']['open']['game_name']; ?></p>
						<?php endif; ?>
						<br />
						<input type="submit" class="" id="app_open_game" name="app_open_game" value="<?php echo localize('OK'); ?>" />
					</form>
					<?php if (!empty($texts['open_down'])) : ?>
					<div><?php echo $texts['open_down']; ?></div>
					<?php endif; ?>
					<h3><a href="#app_index_start" class="panel_link scroll_to_top"><?php echo localize('BACK')?></a></h3>
				</div>
			</div>
			
			<div id="app_index_login_panel" class="panel_item panel_item_app_index">
				<div class="panel_content">
					<?php if (isset($_POST['notifications']['new_user_created'])) :
								if ($_POST['notifications']['new_user_created']) : ?>
					<p class="notification">
					<?php 		echo localize('APP_INDEX_NOTIFICATION_NEW_USER_CREATED'); ?>
					</p>
					<?php 	endif; ?>
					<?php endif; ?>
					<h1><?php echo localize('LOGIN')?></h1>
					
					<div><?php echo $texts['login_up']; ?></div>
					
					<form id="login_form" class="app_form app_index_form" method="post" action="">
						<label for="app[login][username]"><?php echo localize('APP_INDEX_USER_NAME'); ?>: </label><input class="" type="text" name="app[login][username]" id="app[login][username]" value="<?php if(isset($_POST['app']['login']['username'])) echo $_POST['app']['login']['username']; ?>" />
						<?php	if (isset($index_form_errors['app']['login']['username'])) : ?>
						<p class="error"><?php echo $index_form_errors['app']['login']['username']; ?></p>
						<?php endif; ?>
						
						<label for="app[login][password]"><?php echo localize('APP_INDEX_PASSWORD'); ?>: </label><input class="" type="password" name="app[login][password]" id="app[login][password]" value="<?php if(isset($_POST['app']['login']['password'])) echo $_POST['app']['login']['password']; ?>" />
						<?php	if (isset($index_form_errors['app']['login']['password'])) : ?>
						<p class="error"><?php echo $index_form_errors['app']['login']['password']; ?></p>
						<?php endif; ?>
						<br />
						<input type="submit" class="" name="app_login" value="<?php echo localize('OK'); ?>" />
					</form>
					
					<?php if (!empty($texts['login_down'])) : ?>
					<div><?php echo $texts['login_down']; ?></div>
					<?php endif; ?>
					<h3><a href="#app_index_start" class="panel_link"><?php echo localize('BACK')?></a></h3>
				</div>
			</div>
			
			<div id="app_index_register_panel" class="panel_item panel_item_app_index">
				<div class="panel_content">
					<h1><?php echo localize('REGISTER')?></h1>
					<div><?php echo $texts['registration_up']; ?></div>
					
					<form id="register_form" class="app_form app_index_form" method="post" action="">
						<label for="app[register][username]"><?php echo localize('APP_INDEX_USER_NAME'); ?>: </label>
						<input class="" type="text" name="app[register][username]" id="app[register][username]" value="<?php if(isset($_POST['app']['register']['username'])) : echo $_POST['app']['register']['username']; elseif (isset($_SESSION['user']['username'])) : echo $_SESSION['user']['username']; endif; ?>" />
						<?php	if (isset($index_form_errors['app']['register']['username'])) : ?>
						<p class="error"><?php echo $index_form_errors['app']['register']['username']; ?></p>
						<?php endif; ?>
						
						<label for="app[register][password]"><?php echo localize('APP_INDEX_PASSWORD'); ?>: </label><input class="" type="password" name="app[register][password]" id="app[register][password]" value="<?php if(isset($_POST['app']['register']['password'])) echo $_POST['app']['register']['password']; ?>" />
						<?php	if (isset($index_form_errors['app']['register']['password'])) : ?>
						<p class="error"><?php echo $index_form_errors['app']['register']['password']; ?></p>
						<?php endif; ?>
						<label for="app[register][password2]"><?php echo localize('APP_INDEX_PASSWORD2'); ?>: </label><input class="" type="password" name="app[register][password2]" id="app[register][password2]" value="<?php if(isset($_POST['app']['register']['password2'])) echo $_POST['app']['register']['password2']; ?>" />
						<?php	if (isset($index_form_errors['app']['register']['password2'])) : ?>
						<p class="error"><?php echo $index_form_errors['app']['register']['password2']; ?></p>
						<?php endif; ?>
						<br />
						<input type="submit" class="" name="app_register" value="<?php echo localize('OK'); ?>" />
					</form>
					
					<?php if (!empty($texts['registration_down'])) : ?>
					<div><?php echo $texts['registration_down']; ?></div>
					<?php endif; ?>
					<h3><a href="#app_index_start" class="panel_link"><?php echo localize('BACK')?></a></h3>
				</div>
			</div>
			
			<div id="app_index_continue_panel" class="panel_item panel_item_app_index">
				<div class="panel_content">
					<h1><?php echo localize('APP_INDEX_CONTINUE_GAME')?></h1>
					<div><?php echo $texts['continue_up']; ?></div>
					<?php 
						$created_string = '';
						if(isset($_SESSION['game']['profile'])) {
							foreach($user_games as $game) {
								if ($game['profile_id'] == $_SESSION['game']['profile']) {
									$created_string = date(localize('DATE_FORMAT'), strtotime($game['profile_created']));
								}
							}
						}
					?>
					<form id="continue_form" class="app_form app_index_form" method="post" action="">
						<label for="app[index][simulation]"><?php echo localize('GAME'); ?>: </label>
						<input class="" type="text" name="app[index][simulation]" id="app[index][simulation]" value="<?php if(isset($_SESSION['game']['name'])) echo($_SESSION['game']['name'] . ' ' . $created_string); ?>" disabled="disabled" />
						<?php	if (isset($index_form_errors['app']['index']['simulation'])) : ?>
						<p class="error"><?php echo $index_form_errors['app']['index']['simulation']; ?></p>
						<?php endif; ?>
						<br />
						<input type="submit" class="" name="app_continue" value="<?php echo localize('OK'); ?>" />
					</form>
					
					<?php if (!empty($texts['continue_down'])) : ?>
					<div><?php echo $texts['continue_down']; ?></div>
					<?php endif; ?>
					<h3><a href="#app_index_start" class="panel_link"><?php echo localize('BACK')?></a></h3>
				</div>
			</div>
			
		</div> <!-- #panel_mask -->
	</div> <!-- #panel_wrapper -->
	<div class="clear"></div>

	<div class="jqmUserSettings" id="user_settings_modal">
		<a href="#" class="jqmClose" id="user_settings_modal_close"><?php echo localize('CLOSE'); ?></a>
		<h2><?php echo localize('ADMIN_EDITOR_USER_SETTINGS')?></h2>
		<br />
<?php if ($_POST['notifications']['password_changed']) : ?>
		<p class="notification">
			<?php echo localize('ADMIN_EDITOR_NOTIFICATION_PASSWORD_CHANGED'); ?>
		</p>
<?php endif; ?>
		<form id="user_settings_form" class="app_form" method="post" action="">
			<div class="left" id="user_settings_left">
				<label for="user[settings][new_password]"><?php echo localize('ADMIN_EDITOR_CHANGE_PASSWORD')?></label><input class="" type="password" name="user[settings][new_password]" id="user[settings][new_password]" value="<?php if(isset($_POST['user']['settings']['new_password'])) echo $_POST['user']['settings']['new_password']; ?>" />
				<?php	if (isset($index_form_errors['user']['settings']['new_password'])) : ?>
				<p class="error"><?php echo $index_form_errors['user']['settings']['new_password']; ?></p>
				<?php endif; ?>
				<label for="user[settings][new_password2]"><?php echo localize('ADMIN_EDITOR_CHANGE_PASSWORD2')?></label><input class="" type="password" name="user[settings][new_password2]" id="user[settings][new_password2]" value="<?php if(isset($_POST['user']['settings']['new_password2'])) echo $_POST['user']['settings']['new_password2']; ?>" />
				<?php	if (isset($index_form_errors['user']['settings']['new_password2'])) : ?>
				<p class="error"><?php echo $index_form_errors['user']['settings']['new_password2']; ?></p>
				<?php endif; ?>
				<label for="user[settings][current_password]"><?php echo localize('ADMIN_EDITOR_CURRENT_PASSWORD')?></label><input class="" type="password" name="user[settings][current_password]" id="user[settings][current_password]" value="<?php if(isset($_POST['user']['settings']['current_password'])) echo $_POST['user']['settings']['current_password']; ?>" />
				<?php	if (isset($index_form_errors['user']['settings']['current_password'])) : ?>
				<p class="error"><?php echo $index_form_errors['user']['settings']['current_password']; ?></p>
				<?php endif; ?>
				<br />
				<input class="" type="submit" class="" id="change_password" name="change_password" value="<?php echo localize('SAVE')?>" />
			</div>
			<div class="right" id="user_settings_right">
				<button class="right" id="delete_profile_button" name="delete_profile_button"><?php echo localize('ADMIN_EDITOR_DELETE_PROFILE')?></button>
			</div>
			
			<div class="clear"></div>
			<br />
			<?php print_app_saved_games($user_games, $current_simulation); ?>
			<br />
		</form>
	</div>
	
	<?php print_app_delete_saved_game_modal(); ?>
	
	<a id="show_link_profile_modal" href="#"></a>
	<div class="jqmDialog2" id="link_profile_modal">
		<a href="#" class="jqmClose" id="link_profile_modal_close1"><?php echo localize('APP_SIMULATION_STAY_ON_PAGE')?></a>
		<div class="jqmdBL"><div class="jqmdBR"><div class="jqmdBC">
			<div class="jqmdMSG">
				<br />
				<br />
				<br />
				<div class="centered largeText">
					<?php echo localize('APP_SIMULATION_CREATE_USER_AND_LINK_PROFILE')?>
				</div>
				<br />
				<div class="centered buttons">
					<input type="submit" class="jqmClose" id="link_profile_modal_register" value="<?php echo localize("YES"); ?>" />
					<input type="submit" class="jqmClose" id="link_profile_modal_close2" value="<?php echo localize("NO"); ?>" />
				</div>
			</div>
			</div></div>
		</div>
	</div>
	
	<div id="delete_profile_modal" class="jqmDialog jqmdWide">
		<a href="#" class="jqmClose" id="delete_profile_modal_close"><?php echo localize('CLOSE'); ?></a>
		<div class="jqmdBL"><div class="jqmdBR"><div class="jqmdBC">

		<div class="jqmdMSG">
			<br />
			<br />
			<div class="centered largeText">
				<?php echo localize('APP_SIMULATION_CONFIRM_DELETE_PROFILE')?>
			</div>
			<p><?php echo localize('APP_SIMULATION_CONFIRM_DELETE_PROFILE_DESCRIPTION')?></p>
			<br />
			<form method="post" action="#">
				<div class="centered buttons">
					<input type="submit" class="" id="delete_profile_modal_yes_button" name="delete_profile_modal_yes_button" value="<?php echo localize("YES"); ?>" />
					<input type="submit" class="jqmClose" id="delete_profile_modal_no_button" name="delete_profile_modal_no_button" value="<?php echo localize("NO"); ?>" />
				</div>
			</form>
		</div>

		</div></div></div>

	</div>
	
	<a id="show_session_expired" href="#"></a>
	<div class="jqmDialog2" id="session_expired_modal">
		<!--<a href="#" class="jqmClose" id="link_profile_modal_close1"><?php echo localize('APP_SIMULATION_STAY_ON_PAGE')?></a>-->
		<div class="jqmdBL"><div class="jqmdBR"><div class="jqmdBC">
			<div class="jqmdMSG">
				<br />
				<br />
				<br />
				<div class="centered largeText">
					<?php echo localize('SESSION_EXPIRED'); ?>
				</div>
				<br />
				<div class="centered buttons">
					<input type="submit" class="jqmClose" id="session_expired_close" value="<?php echo localize("OK"); ?>" />
					<!--<input type="submit" class="jqmClose" id="link_profile_modal_close2" value="<?php echo localize("NO"); ?>" />-->
				</div>
			</div>
			</div></div>
		</div>
	</div>

<script type="text/JavaScript">
$(document).ready(function() {

	// Show user settings popup when needed
	<?php if ($show_user_settings) : ?>
	$('#user_settings_button').click();
	<?php endif; ?>

	<?php if ($_SESSION['isLogged']) : ?>
	window.showAddAccountPopupOnLeave = false;
	<?php elseif (isset($this_game['use_login']) && !$this_game['use_login']) : ?>
	window.showAddAccountPopupOnLeave = false;
	<?php else: ?>
	$('.log_out').click( function (e) {
		e.preventDefault();
		window.showAddAccountPopupOnLeave = false;
		$('#show_link_profile_modal').click();
	});
	<?php endif; ?>

	// Show the correct view panel in case of errors and some other special cases
	<?php if (isset($_SESSION['active']) && !$_SESSION['active']) : ?>
	$('#show_session_expired').click();
	window.showAddAccountPopupOnLeave = false;
	<?php $_SESSION['active'] = true; ?>
	<?php endif; ?>
	<?php if (isset($form_errors['app']['new'])) : ?>
	$('#app_index_start_new').click();
	<?php endif; ?>
	<?php if (isset($form_errors['app']['open'])) : ?>
	$('#app_index_open').click();
	<?php endif; ?>
	<?php if (isset($form_errors['app']['register'])) : ?>
	$('#app_index_register').click();
	<?php endif; ?>
	<?php if (isset($_GET['showpanel']) && $_GET['showpanel'] == 'app_index_register') : ?>
	$('#app_index_register').click();
	<?php endif; ?>
	<?php if (isset($form_errors['app']['login'])) : ?>
	$('#app_index_login').click();
	<?php endif; ?>
	<?php if (isset($_POST['notifications']['new_user_created'])) : ?>
	$('#app_index_login').click();
	<?php endif; ?>
	
});
</script>
<?php 

print_html_end();
?>