<?php
/**
*	@file Config.class.php
*	@brief Contains definition of Config class.
*/

/** Configuration class. */
class Config {
	/** Config $instance of configuration class. */
	private static $instance = null;
	
	/** string Config::$db_type Type of which database is selected 'mysql' or 'xml'. */
	public $db_type;
	/** string Config::$db_host MySQL host name. */
	public $db_host;
	/** string Config::$db_user MySQL user name. */
	public $db_user;
	/** string Config::$db_pass MySQL password. */
	public $db_pass;
	/** string Config::$db_name MySQL database name. */
	public $db_name;
	/** string Config::$db_port MySQL database port number. */
	public $db_port;
	/** string Config::$db_xml_folder Location of XML folder (subdir). */
	public $db_xml_folder;
	/** string Config::$baseurl The baseurl of GAL2. */
	public $baseurl;
	/** string Config::$basedir Directory of where GAL2 is installed. */
	public $basedir;
	/** string Config::$MAX_FILE_SIZE Maximum file size of uploaded file (8 megabytes by default). */
	public $MAX_FILE_SIZE;
	/** string Config::$php_version Version number of PHP. */
	public $php_version;
	/** bool Config::$debug Tells whether or not to print error messages. */
	private $debug;
	
	function __construct() {
		global $CONF_BASEURL,
			$CONF_DB_TYPE,
        	$CONF_MYSQL_DATABASE,
        	$CONF_MYSQL_HOST,
        	$CONF_MYSQL_USER,
        	$CONF_MYSQL_PASSWORD,
        	$CONF_MYSQL_PORT,
        	$CONF_XML_BASE_FOLDER,
        	$CONF_PHP_VERSION;
      
		$this->debug = true;
		$this->baseurl = $CONF_BASEURL;
		$this->basedir = realpath(dirname(__FILE__)."/../") . "/";

		//Database settings	
		$this->db_type = $CONF_DB_TYPE;
		$this->db_host = $CONF_MYSQL_HOST;
		$this->db_user = $CONF_MYSQL_USER;
		$this->db_pass = $CONF_MYSQL_PASSWORD;
		$this->db_name = $CONF_MYSQL_DATABASE;
		$this->db_port = $CONF_MYSQL_PORT;
		$this->db_xml_folder = $CONF_XML_BASE_FOLDER;
		$this->php_version = $CONF_PHP_VERSION;
		
		if ($this->debug) {
			error_reporting('E_ALL');
 			ini_set("display_errors", 1);
		}
		else {
			error_reporting('E_NONE');
			ini_set("display_errors", 0);
		}
		
		setlocale(LC_ALL, 'fi_FI.UTF-8');
		//8 megabytes...
		$this->MAX_FILE_SIZE = "8388608";
		ini_set("upload_max_filesize", "8M");
	}
	
	/** 
	 * Returns the instance of Config class. Creates it first if not exists.
	 * @return Config
	 */
	public static function getInstance() {
		
		if (is_null(self::$instance)) {
			self::$instance = new Config();
		}
		return self::$instance;
	}
	
	/** 
	 * Method to manually set the base directory.
	 * @param string $dir New base directory for GAL2.
	 * @return void
	 */
	function setBasedir($dir) {
		$this->basedir = $dir;
	}
	
	/** 
	 * Method to get the base domain.
	 * @return string Domain
	 */
	public function getBaseDomain() {
		
		$parts = explode("//", $this->baseurl);
		$parts2 = explode("/", $parts[1]);
 		return $parts[0]. "//" . $parts2[0];
	}
	
	/** 
	 * Method to get the part of url between the base domain and request.
	 * @return string Middle part of url
	 */
	public function getBetweenBaseDomainAndRequest() {
		return substr($this->baseurl, strlen($this->getBaseDomain()));
	}
}
?>