<?php
/**
*	@file FormHandler.class.php
*	@brief A Class for handling, validating and filtering form data
*/

/** A Class for handling, validating and filtering form data */
class FormHandler {
 	
	/** array FormHandler::$_form_error_messages An array of possible error messages. */
	var $_form_error_messages = array();
	/** string FormHandler::$_latest_error The latest error message generated. */
	var $_latest_error = '';
	
	public function __construct() {
		$this->_form_error_messages = array(
			'error' => localize('ERROR_FORM_HANDLER'),
			'empty' => localize('ERROR_FORM_HANDLER_EMPTY'),
			'validate_int' => localize('ERROR_FORM_HANDLER_INT'),	
			'validate_string' => localize('ERROR_FORM_HANDLER_STRING'),
			'validate_email' => localize('ERROR_FORM_HANDLER_EMAIL')
		);
	}
	
	/**
	 * Validate int type.
	 * @param int $int An integer to validate.
	 * @return string|bool Return validated string or false if validation fails or if empty.
	 */
	public function ValidateInt($int) {
		
		if (empty($int)) {
			$this->_latest_error = $this->_form_error_messages['empty'];
			return false;
		}
		$validated_int = filter_var($int, FILTER_VALIDATE_INT);
		
		if($validated_int === false) {
			$this->_latest_error = $this->_form_error_messages['validate_int'];
			return false;
		}
		$this->_latest_error = '';
		
		return intval($validated_int);
	}
	
	
	/**
	 * Sanitize string
    * 
    * Max length is 500 chars by default
    * and it doesn't cut string by default.
    * @param string $string String to sanitize
    * @param int $max_size Maximum size of a string. 500 by default.
    * @param bool $cut_too_long Defines whether or not to cut the string 
    * @return string|bool Sanitized string or false if string is too long or empty.
	 */
	public function SanitizeString($string, $max_size=500, $cut_too_long=false) {
		
		if (empty($string)) {
			$this->_latest_error = $this->_form_error_messages['empty'];
			return false;
		}
		// TODO: add some sanitizer
		//$sanitized_string = filter_var($string, FILTER_SANITIZE_STRING, FILTER_FLAG_STRIP_LOW);
		//$sanitized_string = filter_var($string, FILTER_SANITIZE_FULL_SPECIAL_CHARS);
		$sanitized_string = $string;
		
		// Cut too long string or return false
		if (strlen($sanitized_string) > $max_size) {
			
			if ($cut_too_long) {
				$sanitized_string = substr($sanitized_string, 0, $max_size);
			}
			else {
				$sanitized_string = false;
			}
		}
		if($sanitized_string === false) {
			$this->_latest_error = $this->_form_error_messages['validate_string'];
			return false;
		}
		$this->_latest_error = '';
		return $sanitized_string;
	}
	
	/**
	 * Validate email.
    * 
    * Doesn't cut string by default.
    * @param string $email Email to validate.
    * @param bool $cut_too_long Defines whether or not to cut the email 
    * @return string|bool Validated email or false if validation fails or if string is too long or empty.
	 */
	public function ValidateEmail($email, $cut_too_long=false) {
		
		if (empty($email)) {
			$this->_latest_error = $this->_form_error_messages['empty'];
			return false;
		}
		$validated_email = filter_var($email, FILTER_VALIDATE_EMAIL);
        
		// Cut too long email
		if(strlen($validated_email) > 200) {
			
			if ($cut_too_long) {
				$validated_email = substr($validated_email, 0, 200);
			}
		}
		else {
			$validated_email = false;
		}
		
		if($validated_email === false) {
			$this->_latest_error = $this->_form_error_messages['validate_email'];
			return false;
		}
		$this->_latest_error = '';
		return $validated_email;
	}
}
