<?php
/**
* Define the url path for the resources
*/
defined('LOCALE_PATH') or define('LOCALE_PATH', dirname(__FILE__) . '/../locales/');

/**
* Define the language using language code based on BCP 47 + RFC 4644,
* http://www.rfc-editor.org/rfc/bcp/bcp47.txt
*
* The language files can be found in directory 'lang'
*/
//defined('LANGUAGE') or define('LANGUAGE', 'en-US');
//TODO: tää settingsiin
/*$language = "";

if (isset($SESSION['lang']) || !empty($SESSION['lang'])) {
	$language = $SESSION['lang'];
}
else {
	$language = 'en-US';
}*/

/**
* Load the proper language file and return the translated phrase
*
* The language file is JSON encoded and returns an associative array
* Language filename is determined by BCP 47 + RFC 4646
* http://www.rfc-editor.org/rfc/bcp/bcp47.txt
*
* @param string $phrase The phrase that needs to be translated
* @return string
*/
function localize($phrase) {
	
	global $language;
	global $default_language;
	
   /* Static keyword is used to ensure the file is loaded only once */
   static $translations = NULL;
   static $default_translations = NULL;
   /* If no instance of $translations has occured load the language file */
   if (is_null($translations)) {
		$lang_file = LOCALE_PATH . $language . '.txt';
		/*if (!file_exists($lang_file)) {
			$lang_file = LOCALE_PATH . 'en-US.txt';
		}*/
		$lang_file_content = file_get_contents($lang_file, FILE_USE_INCLUDE_PATH);
		/* Load the language file as a JSON object and transform it into an associative array */
		$translations = json_decode($lang_file_content, true);
	}
	// Same thing to default language
   if (is_null($default_translations)) {
		$lang_file = LOCALE_PATH . $default_language . '.txt';
		$lang_file_content = file_get_contents($lang_file, FILE_USE_INCLUDE_PATH);
		$default_translations = json_decode($lang_file_content, true);
	}
	// Check whether translation is found in given language. if not use default language
	if (!isset($translations[$phrase])) {
		return $default_translations[$phrase];
	}
	return $translations[$phrase];
}