
DROP TABLE IF EXISTS `admin_relationships`;
CREATE TABLE IF NOT EXISTS `admin_relationships` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `game_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `cards`;
CREATE TABLE IF NOT EXISTS `cards` (
  `card_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `card_external_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `game_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `enabled` tinyint(1) unsigned NOT NULL DEFAULT '1',
  `repetitive` tinyint(1) unsigned NOT NULL DEFAULT '0',
  `created` datetime NOT NULL COMMENT 'use NOW() to set this when creating cards',
  `modified` timestamp NULL DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  `creator_id` bigint(20) NOT NULL DEFAULT '0',
  `editor_id` bigint(20) NOT NULL DEFAULT '0',
  `stats` text COLLATE utf8_swedish_ci NOT NULL,
  `comment` text COLLATE utf8_swedish_ci NOT NULL,
  `attachment` text COLLATE utf8_swedish_ci NOT NULL COMMENT 'E.g. picture link',
  PRIMARY KEY (`card_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `card_translations`;
CREATE TABLE IF NOT EXISTS `card_translations` (
  `translation_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `card_id` bigint(20) unsigned NOT NULL,
  `card_name` varchar(255) COLLATE utf8_swedish_ci NOT NULL DEFAULT '',
  `description` text COLLATE utf8_swedish_ci NOT NULL,
  `expert_advice` text COLLATE utf8_swedish_ci NOT NULL,
  `language_code` varchar(7) COLLATE utf8_swedish_ci NOT NULL,
  `is_default` smallint(1) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`translation_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `choices`;
CREATE TABLE IF NOT EXISTS `choices` (
  `choice_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `card_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `ordinal` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`choice_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `choice_translations`;
CREATE TABLE IF NOT EXISTS `choice_translations` (
  `translation_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `choice_id` bigint(20) unsigned NOT NULL,
  `choice_text` text COLLATE utf8_swedish_ci NOT NULL,
  `language_code` varchar(7) COLLATE utf8_swedish_ci NOT NULL,
  `is_default` smallint(1) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`translation_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `ending_conditions`;
CREATE TABLE IF NOT EXISTS `ending_conditions` (
  `condition_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `criteria_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `condition_text` text COLLATE utf8_swedish_ci NOT NULL,
  `condition_logic` varchar(255) COLLATE utf8_swedish_ci NOT NULL DEFAULT '',
  `ordinal` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`condition_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `ending_criteria`;
CREATE TABLE IF NOT EXISTS `ending_criteria` (
  `criteria_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `game_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `result` text COLLATE utf8_swedish_ci NOT NULL,
  `ordinal` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`criteria_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `games`;
CREATE TABLE IF NOT EXISTS `games` (
  `game_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) COLLATE utf8_swedish_ci NOT NULL,
  `created` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `main_admin_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `starting_card_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `panic_card_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `image_folder` varchar(255) COLLATE utf8_swedish_ci NOT NULL DEFAULT '',
  `slug` varchar(255) COLLATE utf8_swedish_ci NOT NULL DEFAULT '',
  `latest_card_id` bigint(20) unsigned NOT NULL DEFAULT '0' COMMENT 'This is for each games internal card ids',
  `use_tags` tinyint(1) unsigned NOT NULL DEFAULT '1',
  `use_stats` tinyint(1) unsigned NOT NULL DEFAULT '1',
  `use_expert_advice` tinyint(1) unsigned NOT NULL DEFAULT '1',
  `use_sudden_scenarios` tinyint(1) unsigned NOT NULL DEFAULT '1',
  `use_ending_criteria` tinyint(1) unsigned NOT NULL DEFAULT '1',
  `use_login` tinyint(1) unsigned NOT NULL DEFAULT '1',
  `use_name` tinyint(1) unsigned NOT NULL DEFAULT '1',
  `multiple_languages` tinyint(1) unsigned NOT NULL DEFAULT '1',
  `show_cards_ending` tinyint(1) unsigned NOT NULL DEFAULT '1',
  `max_cancellations` int(11) NOT NULL DEFAULT '-1' COMMENT '-1 means infinite',
  `background_color` varchar(255) COLLATE utf8_swedish_ci NOT NULL DEFAULT '',
  `text_color` varchar(255) COLLATE utf8_swedish_ci NOT NULL,
  `link_color` varchar(255) COLLATE utf8_swedish_ci NOT NULL,
  `link_hover_color` varchar(255) COLLATE utf8_swedish_ci NOT NULL,
  `button_color` varchar(255) COLLATE utf8_swedish_ci NOT NULL,
  `button_hover_color` varchar(255) COLLATE utf8_swedish_ci NOT NULL,
  `background_tile` text COLLATE utf8_swedish_ci NOT NULL,
  `logo` text COLLATE utf8_swedish_ci NOT NULL,
  `visible_stats` text COLLATE utf8_swedish_ci NOT NULL COMMENT 'List of stats separated with space that are visible to player',
  PRIMARY KEY (`game_id`),
  UNIQUE KEY `name` (`name`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `game_text_translations`;
CREATE TABLE IF NOT EXISTS `game_text_translations` (
  `translation_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `game_id` bigint(20) unsigned NOT NULL,
  `welcome` text COLLATE utf8_swedish_ci NOT NULL,
  `front_up` text COLLATE utf8_swedish_ci NOT NULL,
  `front_down` text COLLATE utf8_swedish_ci NOT NULL,
  `registration_up` text COLLATE utf8_swedish_ci NOT NULL,
  `registration_down` text COLLATE utf8_swedish_ci NOT NULL,
  `login_up` text COLLATE utf8_swedish_ci NOT NULL,
  `login_down` text COLLATE utf8_swedish_ci NOT NULL,
  `new_up` text COLLATE utf8_swedish_ci NOT NULL,
  `new_down` text COLLATE utf8_swedish_ci NOT NULL,
  `open_up` text COLLATE utf8_swedish_ci NOT NULL,
  `open_down` text COLLATE utf8_swedish_ci NOT NULL,
  `continue_up` text COLLATE utf8_swedish_ci NOT NULL,
  `continue_down` text COLLATE utf8_swedish_ci NOT NULL,
  `loading` text COLLATE utf8_swedish_ci NOT NULL,
  `your_life` text COLLATE utf8_swedish_ci NOT NULL,
  `menu` text COLLATE utf8_swedish_ci NOT NULL,
  `selection` text COLLATE utf8_swedish_ci NOT NULL,
  `language_code` varchar(7) COLLATE utf8_swedish_ci NOT NULL,
  `is_default` smallint(1) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`translation_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `played_cards`;
CREATE TABLE IF NOT EXISTS `played_cards` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `profile_id` bigint(20) unsigned NOT NULL,
  `card_id` bigint(20) unsigned NOT NULL,
  `choice_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `result_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `ordinal` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `player_profiles`;
CREATE TABLE IF NOT EXISTS `player_profiles` (
  `profile_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `game_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `user_id` bigint(20) unsigned NOT NULL DEFAULT '0' COMMENT 'only if tied to some user account',
  `player_name` varchar(255) COLLATE utf8_swedish_ci NOT NULL,
  `created` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `cancellations` int(11) unsigned NOT NULL DEFAULT '0',
  `is_panic` tinyint(1) unsigned NOT NULL DEFAULT '0',
  `game_ended` tinyint(1) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`profile_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `results`;
CREATE TABLE IF NOT EXISTS `results` (
  `result_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `choice_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `weight` int(3) unsigned NOT NULL DEFAULT '100',
  `stat_changes` text COLLATE utf8_swedish_ci NOT NULL,
  `next_card_criteria` text COLLATE utf8_swedish_ci NOT NULL,
  `ordinal` int(11) unsigned NOT NULL DEFAULT '0',
  `choice_ordinal` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`result_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `result_translations`;
CREATE TABLE IF NOT EXISTS `result_translations` (
  `translation_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `result_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `result_text` text COLLATE utf8_swedish_ci NOT NULL,
  `language_code` varchar(7) COLLATE utf8_swedish_ci NOT NULL,
  `is_default` smallint(1) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`translation_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `scenario_conditions`;
CREATE TABLE IF NOT EXISTS `scenario_conditions` (
  `condition_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `scenario_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `condition_text` text COLLATE utf8_swedish_ci NOT NULL,
  `condition_logic` varchar(255) COLLATE utf8_swedish_ci NOT NULL DEFAULT '',
  `ordinal` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`condition_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `sudden_scenarios`;
CREATE TABLE IF NOT EXISTS `sudden_scenarios` (
  `scenario_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `game_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `odds` int(3) unsigned NOT NULL DEFAULT '0',
  `result` text COLLATE utf8_swedish_ci NOT NULL,
  `ordinal` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`scenario_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `tags`;
CREATE TABLE IF NOT EXISTS `tags` (
  `tag_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `tag_name` varchar(255) COLLATE utf8_swedish_ci NOT NULL,
  PRIMARY KEY (`tag_id`),
  UNIQUE KEY `tag_name` (`tag_name`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `tag_relationships`;
CREATE TABLE IF NOT EXISTS `tag_relationships` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `tag_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  `card_id` bigint(20) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;

DROP TABLE IF EXISTS `users`;
CREATE TABLE IF NOT EXISTS `users` (
  `user_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `username` varchar(255) COLLATE utf8_swedish_ci NOT NULL,
  `password` varchar(255) COLLATE utf8_swedish_ci NOT NULL,
  PRIMARY KEY (`user_id`),
  UNIQUE KEY `username` (`username`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_swedish_ci AUTO_INCREMENT=0 ;
